--[[
AdiBags - Dragonflight
by Zottelchen
version: 2.0.8
Items from the Dragonflight expansion.
]]

local addonName, addon = ...
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")

local L = addon.L
local MatchIDs
local Result = {}

local function AddToSet(...)
  local Set = {}
  for _, l in ipairs({ ... }) do
    for _, v in ipairs(l) do
      Set[v] = true
    end
  end
  return Set
end

-- Honor Our Ancestors
local HonorOurAncestors_IDs = {
  190327, -- Awakened Air
  191471, -- Writhebark
  193470, -- Feral Hide Drums
  194690, -- Horn o' Mead
  197776, -- Thrice-Spiced Mammoth Kabob
  197788, -- Braised Bruffalon Brisket
  199049, -- Fire-Blessed Greatsword
  200018, -- Enchant Boots - Plainsrunner's Breeze
  202070, -- Exceptional Pelt
}

-- Lizis Reins (Mount)
local LizisReinsMount_IDs = {
  192615, -- Fluorescent Fluid
  192636, -- Woolly Mountain Pelt
  192658, -- High-Fiber Leaf
  194966, -- Thousandbite Piranha
  200598, -- Meluun's Green Curry
}

-- Magmashell (Mount)
local MagmashellMount_IDs = {
  201883, -- Empty Magma Shell
}

-- Otto (Mount)
local OttoMount_IDs = {
  199338, -- Copper Coin of the Isles
  199339, -- Silver Coin of the Isles
  199340, -- Gold Coin of the Isles
  202061, -- ERROR1
  202066, -- ERROR1
  202068, -- ERROR1
  202069, -- ERROR1
  202072, -- Frigid Floe Fish
  202073, -- Calamitous Carp
  202074, -- Kingfin, the Wise Whiskerfish
  202102, -- Immaculate Sac of Swog Treasures
}

-- Scrappy Worldsnail (Mount)
local ScrappyWorldsnailMount_IDs = {
  199215, -- Worldbreaker Membership
  202173, -- Magmote
}

-- Temperamental Skyclaw (Mount)
local TemperamentalSkyclawMount_IDs = {
  201420, -- ERROR1
  201421, -- ERROR1
  201422, -- Flash Frozen Meat
}

-- Tetrachromancer (Achievement)
local TetrachromancerAchievement_IDs = {
  193205, -- Ohuna Companion Color: Brown
  194087, -- Ohuna Companion Color: Red
  194088, -- Ohuna Companion Color: Dark
  194089, -- Bakar Companion Color: Orange
  194090, -- Bakar Companion Color: White
  194091, -- Bakar Companion Color: Golden Brown
  194093, -- Bakar Companion Color: Brown
  194094, -- Bakar Companion Color: Black
  194095, -- Ohuna Companion Color: Sepia
}

-- Bandages
local Bandages_IDs = {
  194048, -- Wildercloth Bandage
  194049, -- Wildercloth Bandage
  194050, -- Wildercloth Bandage
}

-- Cauldrons
local Cauldrons_IDs = {
  191482, -- Potion Cauldron of Power
  191483, -- Potion Cauldron of Power
  191484, -- Potion Cauldron of Power
  191485, -- Potion Cauldron of Ultimate Power
  191486, -- Potion Cauldron of Ultimate Power
  191487, -- Potion Cauldron of Ultimate Power
  191488, -- Cauldron of the Pooka
  191489, -- Cauldron of the Pooka
  191490, -- Cauldron of the Pooka
}

-- Contracts
local Contracts_IDs = {
  198494, -- Contract: Iskaara Tuskarr
  198495, -- Contract: Iskaara Tuskarr
  198496, -- Contract: Iskaara Tuskarr
  198497, -- Contract: Valdrakken Accord
  198498, -- Contract: Valdrakken Accord
  198499, -- Contract: Valdrakken Accord
  198500, -- Contract: Maruuk Centaur
  198501, -- Contract: Maruuk Centaur
  198502, -- Contract: Maruuk Centaur
  198503, -- Contract: Artisan's Consortium
  198504, -- Contract: Artisan's Consortium
  198505, -- Contract: Artisan's Consortium
  198506, -- Contract: Dragonscale Expedition
  198507, -- Contract: Dragonscale Expedition
  198508, -- Contract: Dragonscale Expedition
}

-- Crafting Potions
local CraftingPotions_IDs = {
  191342, -- Aerated Phial of Deftness
  191343, -- Aerated Phial of Deftness
  191344, -- Aerated Phial of Deftness
  191345, -- Steaming Phial of Finesse
  191346, -- Steaming Phial of Finesse
  191347, -- Steaming Phial of Finesse
  191354, -- Crystalline Phial of Perception
  191355, -- ERROR2
  191356, -- Crystalline Phial of Perception
  197720, -- Aerated Phial of Quick Hands
  197721, -- Aerated Phial of Quick Hands
  197722, -- Aerated Phial of Quick Hands
}

-- Food
local Food_IDs = {
  191050, -- 10.0 Food/Drink Template - Food Only - Level 65 - Required Level 60
  191051, -- 10.0 Food/Drink Template - Food Only - Level 70 - Required Level 65
  191052, -- 10.0 Food/Drink Template - Drink Only - Level 65 - Required Level 60
  191053, -- 10.0 Food/Drink Template - Drink Only - Level 70 - Required Level 65
  191056, -- 10.0 Food/Drink Template - Both Health and Mana - Level 70 - Required Level 65
  191062, -- 10 Food/Drink Template - Alcohol - Weak
  191063, -- 10 Food/Drink Template - Alcohol - Potent
  191064, -- 10 Food/Drink Template - Alcohol - Strong
  191917, -- Suspiciously Fuzzy Drink
  191918, -- Suspiciously Fuzzy Drink
  191919, -- Suspiciously Fuzzy Drink
  193859, -- Twice-Burnt Potato
  194680, -- Jerky Surprise
  194681, -- Sugarwing Cupcake
  194682, -- Mother's Gift
  194683, -- Buttermilk
  194684, -- Azure Leywine
  194685, -- Dragonspring Water
  194686, -- Spicy Musken Drummies
  194688, -- Vorquin Filet
  194689, -- Anchovy Crisps
  194690, -- Horn o' Mead
  194691, -- Artisanal Berry Juice
  194692, -- Distilled Fish Juice
  194693, -- Improvised Sushi
  194694, -- Seasoned Hornswog Steak
  194695, -- Ramloaf
  195455, -- Argali Cheese
  195456, -- Plains Flatbread
  195457, -- Mammoth Jerky
  195458, -- Forager's Stew
  195459, -- Argali Milk
  195460, -- Fermented Musken Milk
  195462, -- Fried Hornstrider Wings
  195463, -- Seasoned Mudstomper Belly
  195464, -- Sweetened Broadhoof Milk
  195465, -- Stormwing Egg Breakfast
  195466, -- Frenzy and Chips
  196440, -- Dragon Flight
  196540, -- Broadhoof Tail Poutine
  196582, -- Syrup-Drenched Toast
  196583, -- Greenberry Toast
  196584, -- Acorn Milk
  196585, -- Plainswheat Pretzel
  197758, -- Twice-Baked Potato
  197759, -- Cheese and Quackers
  197760, -- Mackerel Snackerel
  197761, -- Probably Protein
  197762, -- Sweet and Sour Clam Chowder
  197763, -- Breakfast of Draconic Champions
  197766, -- Snow in a Cone
  197767, -- Blubbery Muffin
  197768, -- Celebratory Cake
  197769, -- Tasty Hatchling's Treat
  197770, -- Zesty Water
  197771, -- Delicious Dragon Spittle
  197772, -- Churnbelly Tea
  197774, -- Charred Hornswog Steaks
  197775, -- Scrambled Basilisk Eggs
  197776, -- Thrice-Spiced Mammoth Kabob
  197777, -- Hopefully Healthy
  197778, -- Timely Demise
  197779, -- Filet of Fangs
  197780, -- Seamoth Surprise
  197781, -- Salt-Baked Fishcake
  197782, -- Feisty Fish Sticks
  197783, -- Aromatic Seafood Platter
  197784, -- Sizzling Seafood Medley
  197785, -- Revenge, Served Cold
  197786, -- Thousandbone Tongueslicer
  197787, -- Great Cerulean Sea
  197788, -- Braised Bruffalon Brisket
  197789, -- Riverside Picnic
  197790, -- Roast Duck Delight
  197791, -- Salted Meat Mash
  197792, -- Fated Fortune Cookie
  197793, -- Yusa's Hearty Stew
  197794, -- Grand Banquet of the Kalu'ak
  197795, -- Hoard of Draconic Delicacies
  197847, -- Gorloc Fin Soup
  197848, -- Hearty Squash Stew
  197849, -- Ancient Firewine
  197850, -- Mammoth Dumpling
  197851, -- Extra Crispy Mutton
  197852, -- Goat Brisket
  197853, -- Critter Kebab
  197854, -- Enchanted Argali Tenderloin
  197855, -- Explorer's Mix
  197856, -- Cup o' Wakeup
  197857, -- Swog Slurp
  197858, -- Salt-Baked Scalebelly
  198356, -- Honey Snack
  198440, -- Discounted Meat
  198441, -- Thunderspine Tenders
  198830, -- Conjured Tasty Hatchling's Treat
  198831, -- Conjured Snow in a Cone
  198832, -- Conjured Blubbery Muffin
  198833, -- Conjured Celebratory Cake
  200099, -- M.R.E.
  200304, -- Stored Dracthyr Rations
  200305, -- Dracthyr Water Rations
  200619, -- Scaralesh's Special
  200680, -- Maruukai Mule
  200681, -- Ohn Lite
  200855, -- Tuskarr Port Wine
  200856, -- Sideboat
  200862, -- Experimental Duck Feed
  200871, -- Steamed Scarab Steak
  200953, -- Wild Dragon Fruit
  200966, -- Wild Truffle
  201045, -- Icecrown Bleu
  201046, -- Dreamwarding Dripbrew
  201047, -- Arcanostabilized Provisions
  201089, -- Craft Creche Crowler
  201090, -- Bivigosa's Blood Sausages
  201327, -- Emerald Dreamtime
  201398, -- Mogu Mozzarella
  201413, -- Eternity-Infused Burrata
  201415, -- Temporal Parmesan
  201416, -- Black Empire Brunost
  201417, -- Curding of Stratholme
  201419, -- Apexis Asiago
  201469, -- Emerald Green Apple
  201697, -- Coldarra Coldbrew
  201698, -- Black Dragon Red Eye
  201721, -- Life Fire Latte
  201725, -- Flappuccino
  201813, -- Spoiled Firewine
  201820, -- Silithus Swiss
  202033, -- Slippery Salmon
  202063, -- Flopping Tilapia
  202108, -- Bouncing Bass
}

-- Incense
local Incense_IDs = {
  191499, -- Sagacious Incense
  191500, -- Sagacious Incense
  191501, -- Sagacious Incense
  191502, -- Somniferous Incense
  191503, -- Somniferous Incense
  191504, -- Somniferous Incense
  191505, -- Exultant Incense
  191506, -- Exultant Incense
  191507, -- Exultant Incense
  191508, -- Fervid Incense
  191509, -- Fervid Incense
  191510, -- Fervid Incense
}

-- Phials
local Phials_IDs = {
  191318, -- Phial of the Eye in the Storm
  191319, -- Phial of the Eye in the Storm
  191320, -- Phial of the Eye in the Storm
  191321, -- Phial of Still Air
  191322, -- Phial of Still Air
  191323, -- Phial of Still Air
  191324, -- Phial of Icy Preservation
  191325, -- Phial of Icy Preservation
  191326, -- Phial of Icy Preservation
  191327, -- Iced Phial of Corrupting Rage
  191328, -- Iced Phial of Corrupting Rage
  191329, -- Iced Phial of Corrupting Rage
  191330, -- Phial of Charged Isolation
  191331, -- Phial of Charged Isolation
  191332, -- Phial of Charged Isolation
  191333, -- Phial of Glacial Fury
  191334, -- Phial of Glacial Fury
  191335, -- Phial of Glacial Fury
  191336, -- Phial of Static Empowerment
  191337, -- Phial of Static Empowerment
  191338, -- Phial of Static Empowerment
  191339, -- Phial of Tepid Versatility
  191340, -- Phial of Tepid Versatility
  191341, -- Phial of Tepid Versatility
  191348, -- Charged Phial of Alacrity
  191349, -- Charged Phial of Alacrity
  191350, -- Charged Phial of Alacrity
  191357, -- Phial of Elemental Chaos
  191358, -- Phial of Elemental Chaos
  191359, -- Phial of Elemental Chaos
}

-- Potions
local Potions_IDs = {
  191351, -- Potion of Frozen Fatality
  191352, -- Potion of Frozen Fatality
  191353, -- Potion of Frozen Fatality
  191360, -- Bottled Putrescence
  191361, -- Bottled Putrescence
  191362, -- Bottled Putrescence
  191363, -- Potion of Frozen Focus
  191364, -- Potion of Frozen Focus
  191365, -- Potion of Frozen Focus
  191366, -- Potion of Chilled Clarity
  191367, -- Potion of Chilled Clarity
  191368, -- Potion of Chilled Clarity
  191369, -- Potion of Withering Vitality
  191370, -- Potion of Withering Vitality
  191371, -- Potion of Withering Vitality
  191372, -- Residual Neural Channeling Agent
  191373, -- Residual Neural Channeling Agent
  191374, -- Residual Neural Channeling Agent
  191375, -- Delicate Suspension of Spores
  191376, -- Delicate Suspension of Spores
  191377, -- Delicate Suspension of Spores
  191378, -- Refreshing Healing Potion
  191379, -- Refreshing Healing Potion
  191380, -- Refreshing Healing Potion
  191381, -- Elemental Potion of Ultimate Power
  191382, -- Elemental Potion of Ultimate Power
  191383, -- Elemental Potion of Ultimate Power
  191384, -- Aerated Mana Potion
  191385, -- Aerated Mana Potion
  191386, -- Aerated Mana Potion
  191387, -- Elemental Potion of Power
  191388, -- Elemental Potion of Power
  191389, -- Elemental Potion of Power
  191393, -- Potion of the Hushed Zephyr
  191394, -- Potion of the Hushed Zephyr
  191395, -- Potion of the Hushed Zephyr
  191396, -- Potion of Gusts
  191397, -- Potion of Gusts
  191398, -- Potion of Gusts
  191399, -- Potion of Shocking Disclosure
  191400, -- Potion of Shocking Disclosure
  191401, -- Potion of Shocking Disclosure
  191905, -- Fleeting Elemental Potion of Power
  191906, -- Fleeting Elemental Potion of Power
  191907, -- Fleeting Elemental Potion of Power
  191912, -- Fleeting Elemental Potion of Ultimate Power
  191913, -- Fleeting Elemental Potion of Ultimate Power
  191914, -- Fleeting Elemental Potion of Ultimate Power
  194337, -- Liquid Courage
}

-- Ruby Feast
local RubyFeast_IDs = {
  200759, -- Aruunem Berrytart
  200885, -- Cinna-Cinderbloom Tea
  200886, -- Lemon Silverleaf Tea
  200887, -- Charred Porter
  200888, -- Coal-Fired Rib Rack
  200889, -- Highly-Spiced Haunch
  200890, -- Stonetalon Bloom Skewer
  200891, -- Druidic Dreamsalad
  200892, -- Dragonfruit Punch
  200893, -- Azsunian-Poached Lobster
  200894, -- Rare Vintage Arcwine
  200895, -- Fine Taladorian Cheese Platter
  200896, -- Captain's Caramelized Catfish
  200897, -- Venrik's Goat Milk
  200898, -- Mantis Shrimp Cocktail
  200899, -- Seared Sea Mist Noodles
  200900, -- Fried Emperor Wraps
  200901, -- Roquefort-Stuffed Peppers
  200902, -- Ravenberry Panacotta Delight
  200903, -- Moira's Choice Espresso
  200904, -- Picante Pomfruit Cake
}

-- Runes
local Runes_IDs = {
  194817, -- Howling Rune
  194819, -- Howling Rune
  194820, -- Howling Rune
  194821, -- Buzzing Rune
  194822, -- Buzzing Rune
  194823, -- Buzzing Rune
  194824, -- Chirping Rune
  194825, -- Chirping Rune
  194826, -- Chirping Rune
  198491, -- Vantus Rune: Vault of the Incarnates
  198492, -- Vantus Rune: Vault of the Incarnates
  198493, -- Vantus Rune: Vault of the Incarnates
}

-- Statues
local Statues_IDs = {
  193007, -- Narcissist's Sculpture
  193008, -- Narcissist's Sculpture
  193009, -- Narcissist's Sculpture
  193011, -- Revitalizing Red Carving
  193012, -- Revitalizing Red Carving
  193013, -- Revitalizing Red Carving
  193015, -- Statue of Tyr's Herald
  193016, -- Statue of Tyr's Herald
  193017, -- Statue of Tyr's Herald
  193019, -- Djaradin's Pinata
  193020, -- Djaradin's Pinata
  193021, -- Djaradin's Pinata
  194723, -- Kalu'ak Figurine
  194724, -- Kalu'ak Figurine
  194725, -- Kalu'ak Figurine
}

-- Tools
local Tools_IDs = {
  191256, -- Serevite Skeleton Key
  193470, -- Feral Hide Drums
  195580, -- Suspicious Bottle
  198250, -- Convincingly Realistic Jumper Cables
  198251, -- Convincingly Realistic Jumper Cables
  198252, -- Convincingly Realistic Jumper Cables
  198275, -- S.A.V.I.O.R.
  198276, -- S.A.V.I.O.R.
  198277, -- S.A.V.I.O.R.
  198442, -- Bogthwottle's Shrinky-Do
  198836, -- Arclight Vital Correctors
  200121, -- Potion of Beginner's Luck
  201325, -- Draconic Augment Rune
  201427, -- Fleeting Sands
  201428, -- Quicksilver Sands
  201436, -- Temporally-Locked Sands
  201438, -- Weary Sands
}

-- Awakened Elementals
local AwakenedElementals_IDs = {
  190316, -- Awakened Earth
  190321, -- Awakened Fire
  190324, -- Awakened Order
  190327, -- Awakened Air
  190329, -- Awakened Frost
  190331, -- Awakened Decay
  190450, -- Awakened Ire
}

-- Rousing Elementals
local RousingElementals_IDs = {
  190315, -- Rousing Earth
  190320, -- Rousing Fire
  190322, -- Rousing Order
  190326, -- Rousing Air
  190328, -- Rousing Frost
  190330, -- Rousing Decay
  190451, -- Rousing Ire
}

-- General Crafting Reagents
local GeneralCraftingReagents_IDs = {
  190453, -- Spark of Ingenuity
  190454, -- Primal Chaos
  190455, -- Concentrated Primal Focus
  190456, -- Artisan's Mettle
  191493, -- Primal Convergent
  191494, -- Primal Convergent
  191495, -- Primal Convergent
  191496, -- Omnium Draconis
  191497, -- Omnium Draconis
  191498, -- Omnium Draconis
  191529, -- Illustrious Insight
  197921, -- Primal Infusion
  198046, -- Concentrated Primal Infusion
  198048, -- Titan Training Matrix I
  198056, -- Titan Training Matrix II
  198058, -- Titan Training Matrix III
  198059, -- Titan Training Matrix IV
  200686, -- Primal Focus
  200860, -- Draconic Stopper
  201399, -- Primal Bear Spine
  201400, -- Aquatic Maw
  201401, -- Iridescent Plume
  201402, -- Large Sturdy Femur
  201403, -- Mastodon Tusk
  201404, -- Tallstrider Sinew
  201405, -- Tuft of Primal Wool
  201406, -- Glowing Titan Orb
}

-- Profession Gear
local ProfessionGear_IDs = {
  191223, -- Khaz'gorite Pickaxe
  191224, -- Khaz'gorite Sickle
  191225, -- Khaz'gorite Skinning Knife
  191226, -- Khaz'gorite Needle Set
  191227, -- Khaz'gorite Leatherworker's Knife
  191228, -- Black Dragon Touched Hammer
  191229, -- Khaz'gorite Leatherworker's Toolset
  191230, -- Khaz'gorite Blacksmith's Toolbox
  191231, -- Alchemist's Brilliant Mixing Rod
  191232, -- Chef's Splendid Rolling Pin
  191233, -- Chef's Smooth Rolling Pin
  191234, -- Alchemist's Sturdy Mixing Rod
  191235, -- Draconium Blacksmith's Toolbox
  191236, -- Draconium Leatherworker's Toolset
  191237, -- Draconium Blacksmith's Hammer
  191238, -- Draconium Leatherworker's Knife
  191239, -- Draconium Needle Set
  191240, -- Draconium Skinning Knife
  191241, -- Draconium Sickle
  191242, -- Draconium Pickaxe
  191888, -- Khaz'gorite Blacksmith's Hammer
  193035, -- Bold-Print Bifocals
  193036, -- Left-Handed Magnifying Glass
  193037, -- Sundered Onyx Loupe
  193038, -- Chromatic Focus
  193039, -- Fine-Print Trifocals
  193040, -- Magnificent Margin Magnifier
  193041, -- Alexstraszite Loupes
  193042, -- Resonant Focus
  193479, -- Floral Basket
  193480, -- Durable Pack
  193482, -- Skinner's Cap
  193485, -- Protective Gloves
  193486, -- Resilient Smock
  193487, -- Alchemist's Hat
  193488, -- Lavish Floral Pack
  193489, -- Reinforced Pack
  193490, -- Expert Skinner's Cap
  193491, -- Shockproof Gloves
  193492, -- Masterwork Smock
  193493, -- Expert Alchemist's Hat
  193528, -- Wildercloth Alchemist's Robe
  193529, -- Wildercloth Fishing Cap
  193533, -- Master's Wildercloth Enchanter's Hat
  193534, -- Wildercloth Chef's Hat
  193538, -- Wildercloth Gardening Hat
  193539, -- Wildercloth Enchanter's Hat
  193540, -- Dragoncloth Tailoring Vestments
  193541, -- Wildercloth Tailor's Coat
  193542, -- Master's Wildercloth Gardening Hat
  193543, -- Master's Wildercloth Fishing Cap
  193544, -- Master's Wildercloth Alchemist's Robe
  193545, -- Master's Wildercloth Chef's Hat
  193612, -- Smithing Apron
  193613, -- Flameproof Apron
  193615, -- Jeweler's Cover
  193616, -- Resplendent Cover
  194125, -- Spring-Loaded Draconium Fabric Cutters
  194126, -- Spring-Loaded Khaz'gorite Fabric Cutters
  194874, -- Scribe's Fastened Quill
  194875, -- Scribe's Resplendent Quill
  198204, -- Draconium Brainwave Amplifier
  198205, -- Khaz'gorite Brainwave Amplifier
  198225, -- Draconium Fisherfriend
  198226, -- Khaz'gorite Fisherfriend
  198234, -- Lapidary's Draconium Clamps
  198235, -- Lapidary's Khaz'gorite Clamps
  198243, -- Draconium Delver's Helmet
  198244, -- Khaz'gorite Delver's Helmet
  198245, -- Draconium Encased Samophlange
  198246, -- Khaz'gorite Encased Samophlange
  198262, -- Bottomless Stonecrust Ore Satchel
  198263, -- Bottomless Mireslush Ore Satchel
  198715, -- Runed Draconium Rod
  198716, -- Runed Khaz'gorite Rod
  201601, -- Runed Serevite Rod
}

-- Profession Knowledge
local ProfessionKnowledge_IDs = {
  192131, -- Valdrakken Weapon Chain
  192132, -- Draconium Blade Sharpener
  192443, -- Element-Infused Rocket Helmet
  193891, -- Experimental Substance
  193897, -- Reawakened Catalyst
  193898, -- Umbral Bone Needle
  193899, -- Primalweave Spindle
  193900, -- Prismatic Focusing Shard
  193901, -- Primal Dust
  193902, -- Eroded Titan Gizmo
  193903, -- Watcher Power Core
  193904, -- Phoenix Feather Quill
  193905, -- Iskaaran Trading Ledger
  193907, -- Chipped Tyrstone
  193909, -- Ancient Gem Fragments
  193910, -- Molted Dragon Scales
  193913, -- Preserved Animal Parts
  194039, -- Heated Ore Sample
  194040, -- Slateskin Hide
  194041, -- Driftbloom Sprout
  194042, -- Explorer's Banner of Herbology
  194043, -- Explorer's Banner of Herbology
  194044, -- Explorer's Banner of Herbology
  194045, -- Explorer's Banner of Geology
  194046, -- Explorer's Banner of Geology
  194047, -- Explorer's Banner of Geology
  194054, -- Dredged Seedling
  194055, -- Primordial Soil
  194061, -- Suffocating Spores
  194062, -- Unyielding Stone Chunk
  194063, -- Glowing Fragment
  194064, -- Intricate Geode
  194078, -- Perfect Draconium Scale
  194079, -- Pure Serevite Nugget
  194080, -- Peculiar Bud
  194081, -- Mutated Root
  194697, -- Draconic Treatise on Alchemy
  194698, -- Draconic Treatise on Tailoring
  194699, -- Draconic Treatise on Inscription
  194700, -- Draconic Treatise on Leatherworking
  194702, -- Draconic Treatise on Enchanting
  194703, -- Draconic Treatise on Jewelcrafting
  194704, -- Draconic Treatise on Herbalism
  194708, -- Draconic Treatise on Mining
  198156, -- Wyrmhole Generator
  198454, -- Draconic Treatise on Blacksmithing
  198510, -- Draconic Treatise on Engineering
  198518, -- Professor Instructaur's Top Secret Guide to Blacksmithing
  198519, -- Professor Instructaur's Top Secret Guide to Alchemy
  198520, -- Professor Instructaur's Top Secret Guide to Enchanting
  198521, -- Professor Instructaur's Top Secret Guide to Engineering
  198522, -- Professor Instructaur's Top Secret Guide to Herbalism
  198523, -- Professor Instructaur's Top Secret Guide to Inscription
  198524, -- Professor Instructaur's Top Secret Guide to Jewelcrafting
  198525, -- Professor Instructaur's Top Secret Guide to Leatherworking
  198526, -- Professor Instructaur's Top Secret Guide to Mining
  198527, -- Professor Instructaur's Top Secret Guide to Skinning
  198528, -- Professor Instructaur's Top Secret Guide to Tailoring
  198599, -- Experimental Decay Sample
  198606, -- Blacksmith's Writ
  198607, -- Scribe's Glyphs
  198608, -- Alchemy Notes
  198609, -- Tailoring Examples
  198610, -- Enchanter's Script
  198611, -- Engineering Details
  198612, -- Jeweler's Cuts
  198613, -- Leatherworking Designs
  198656, -- Painter's Pretty Jewel
  198658, -- Decay-Infused Tanning Oil
  198659, -- Forgetful Apprentice's Tome
  198660, -- Fragmented Key
  198662, -- Intriguing Bolt of Blue Cloth
  198663, -- Frostforged Potion
  198664, -- Crystalline Overgrowth
  198667, -- Spare Djaradin Tools
  198669, -- How to Train Your Whelpling
  198670, -- Lofty Malygite
  198675, -- Lava-Infused Seed
  198680, -- Decaying Brackenhide Blanket
  198682, -- Alexstraszite Cluster
  198683, -- Treated Hides
  198684, -- Miniature Bronze Dragonflight Banner
  198685, -- Well Insulated Mug
  198686, -- Frosted Parchment
  198687, -- Closely Guarded Shiny
  198689, -- Stormbound Horn
  198690, -- Decayed Scales
  198692, -- Noteworthy Scrap of Carpet
  198693, -- Dusty Darkmoon Card
  198694, -- Enriched Earthen Shard
  198696, -- Wind-Blessed Hide
  198697, -- Contraband Concoction
  198699, -- Mysterious Banner
  198702, -- Itinerant Singed Fabric
  198703, -- Sign Language Reference Sheet
  198704, -- Pulsing Earth Rune
  198710, -- Canteen of Suspicious Water
  198711, -- Poacher's Pack
  198712, -- Firewater Powder Sample
  198789, -- Intact Coil Capacitor
  198798, -- Flashfrozen Scroll
  198799, -- Forgotten Arcane Tome
  198800, -- Fractured Titanic Sphere
  198837, -- Curious Hide Scraps
  198841, -- Large Sample of Curious Hide
  198963, -- Decaying Phlegm
  198964, -- Elementious Splinter
  198965, -- Primeval Earth Fragment
  198966, -- Molten Globule
  198967, -- Primordial Aether
  198968, -- Primalist Charm
  198969, -- Keeper's Mark
  198970, -- Infinitely Attachable Pair o' Docks
  198971, -- Curious Djaradin Rune
  198972, -- Draconic Glamour
  198973, -- Incandescent Curio
  198974, -- Elegantly Engraved Embellishment
  198975, -- Ossified Hide
  198976, -- Exceedingly Soft Skin
  198977, -- Ohn'arhan Weave
  198978, -- Stupidly Effective Stitchery
  199115, -- Herbalism Field Notes
  199122, -- Mining Field Notes
  199128, -- Skinning Field Notes
  200677, -- Dreambloom Petal
  200678, -- Dreambloom
  200972, -- Dusty Blacksmith's Diagrams
  200973, -- Dusty Scribe's Runic Drawings
  200974, -- Dusty Alchemist's Research
  200975, -- Dusty Tailor's Diagrams
  200976, -- Dusty Enchanter's Research
  200977, -- Dusty Engineer's Scribblings
  200978, -- Dusty Jeweler's Illustrations
  200979, -- Dusty Leatherworker's Diagrams
  200980, -- Dusty Herbalist's Notes
  200981, -- Dusty Miner's Notes
  200982, -- Dusty Skinner's Notes
  201003, -- Furry Gloop
  201004, -- Ancient Spear Shards
  201005, -- Curious Ingots
  201006, -- Draconic Flux
  201007, -- Ancient Monument
  201008, -- Molten Ingot
  201009, -- Falconer Gauntlet Drawings
  201010, -- Qalashi Weapon Diagram
  201011, -- Spelltouched Tongs
  201012, -- Enchanted Debris
  201013, -- Faintly Enchanted Remains
  201014, -- Boomthyr Rocket
  201015, -- Counterfeit Darkmoon Deck
  201016, -- Harmonic Crystal Harmonizer
  201017, -- Igneous Gem
  201018, -- Well-Danced Drum
  201019, -- Ancient Dragonweave Bolt
  201020, -- Silky Surprise
  201023, -- Draconic Treatise on Skinning
  201268, -- Rare Blacksmith's Diagrams
  201269, -- Rare Scribe's Runic Drawings
  201270, -- Rare Alchemist's Research
  201271, -- Rare Tailor's Diagrams
  201272, -- Rare Enchanter's Research
  201273, -- Rare Engineer's Scribblings
  201274, -- Rare Jeweler's Illustrations
  201275, -- Rare Leatherworker's Diagrams
  201276, -- Rare Herbalist's Notes
  201277, -- Rare Miner's Notes
  201278, -- Rare Skinner's Notes
  201279, -- Ancient Blacksmith's Diagrams
  201280, -- Ancient Scribe's Runic Drawings
  201281, -- Ancient Alchemist's Research
  201282, -- Ancient Tailor's Diagrams
  201283, -- Ancient Enchanter's Research
  201284, -- Ancient Engineer's Scribblings
  201285, -- Ancient Jeweler's Illustrations
  201286, -- Ancient Leatherworker's Diagrams
  201287, -- Ancient Herbalist's Notes
  201288, -- Ancient Miner's Notes
  201289, -- Ancient Skinner's Notes
  201300, -- Iridescent Ore Fragments
  201301, -- Iridescent Ore
  201356, -- Glimmer of Fire
  201357, -- Glimmer of Frost
  201358, -- Glimmer of Air
  201359, -- Glimmer of Earth
  201360, -- Glimmer of Order
  201700, -- Notebook of Crafting Knowledge
  201705, -- Notebook of Crafting Knowledge
  201706, -- Notebook of Crafting Knowledge
  201708, -- Notebook of Crafting Knowledge
  201709, -- Notebook of Crafting Knowledge
  201710, -- Notebook of Crafting Knowledge
  201711, -- Notebook of Crafting Knowledge
  201712, -- Notebook of Crafting Knowledge
  201713, -- Notebook of Crafting Knowledge
  201715, -- Notebook of Crafting Knowledge
  201716, -- Notebook of Crafting Knowledge
  201717, -- Notebook of Crafting Knowledge
  202011, -- Elementally-Charged Stone
  202014, -- Infused Pollen
  202016, -- Saturated Bone
}

-- Darkmoon Cards
local DarkmoonCards_IDs = {
  194785, -- Ace of Fire
  194786, -- Two of Fire
  194787, -- Three of Fire
  194788, -- Four of Fire
  194789, -- Five of Fire
  194790, -- Six of Fire
  194791, -- Seven of Frost
  194792, -- Eight of Fire
  194793, -- Ace of Frost
  194794, -- Two of Frost
  194795, -- Three of Frost
  194796, -- Four of Frost
  194797, -- Five of Frost
  194798, -- Six of Frost
  194799, -- Seven of Fire
  194800, -- Eight of Frost
  194801, -- Ace of Air
  194802, -- Two of Air
  194803, -- Three of Air
  194804, -- Four of Air
  194805, -- Five of Air
  194806, -- Six of Air
  194807, -- Seven of Air
  194808, -- Eight of Air
  194809, -- Ace of Earth
  194810, -- Two of Earth
  194811, -- Three of Earth
  194812, -- Four of Earth
  194813, -- Five of Earth
  194814, -- Six of Earth
  194815, -- Seven of Earth
  194816, -- Eight of Earth
  194827, -- Bundle O' Cards: Dragon Isles
  198614, -- Soggy Clump of Darkmoon Cards
}

-- Drakewatcher Manuscripts
local DrakewatcherManuscripts_IDs = {
  192111, -- Renewed Proto-Drake: Red Scales
  192523, -- Renewed Proto-Drake: Green Scales
  196961, -- Cliffside Wylderdrake: Armor
  196962, -- Cliffside Wylderdrake: Silver and Purple Armor
  196963, -- Cliffside Wylderdrake: Silver and Blue Armor
  196964, -- Cliffside Wylderdrake: Gold and Black Armor
  196965, -- Cliffside Wylderdrake: Bronze and Teal Armor
  196966, -- Cliffside Wylderdrake: Gold and Orange Armor
  196967, -- Cliffside Wylderdrake: Gold and White Armor
  196968, -- Cliffside Wylderdrake: Steel and Yellow Armor
  196969, -- Cliffside Wylderdrake: Finned Back
  196970, -- Cliffside Wylderdrake: Spiked Back
  196971, -- Cliffside Wylderdrake: Spiked Brow
  196972, -- Cliffside Wylderdrake: Plated Brow
  196973, -- Cliffside Wylderdrake: Dual Horned Chin
  196974, -- Cliffside Wylderdrake: Four Horned Chin
  196975, -- Cliffside Wylderdrake: Head Fin
  196976, -- Cliffside Wylderdrake: Head Mane
  196977, -- Cliffside Wylderdrake: Split Head Horns
  196978, -- Cliffside Wylderdrake: Small Head Spikes
  196979, -- Cliffside Wylderdrake: Curled Head Horns
  196980, -- Cliffside Wylderdrake: Triple Head Horns
  196981, -- Cliffside Wylderdrake: Conical Head
  196982, -- Cliffside Wylderdrake: Ears
  196983, -- Cliffside Wylderdrake: Maned Jaw
  196984, -- Cliffside Wylderdrake: Finned Jaw
  196985, -- Cliffside Wylderdrake: Horned Jaw
  196986, -- Cliffside Wylderdrake: Black Hair
  196987, -- Cliffside Wylderdrake: Blonde Hair
  196988, -- Cliffside Wylderdrake: Red Hair
  196989, -- Cliffside Wylderdrake: White Hair
  196990, -- Cliffside Wylderdrake: Helm
  196991, -- Cliffside Wylderdrake: Black Horns
  196992, -- Cliffside Wylderdrake: Heavy Horns
  196993, -- Cliffside Wylderdrake: Sleek Horns
  196994, -- Cliffside Wylderdrake: Short Horns
  196995, -- Cliffside Wylderdrake: Spiked Horns
  196996, -- Cliffside Wylderdrake: Branched Horns
  196997, -- Cliffside Wylderdrake: Split Horns
  196998, -- Cliffside Wylderdrake: Hook Horns
  196999, -- Cliffside Wylderdrake: Swept Horns
  197000, -- Cliffside Wylderdrake: Coiled Horns
  197001, -- Cliffside Wylderdrake: Finned Cheek
  197002, -- Cliffside Wylderdrake: Flared Cheek
  197003, -- Cliffside Wylderdrake: Spiked Cheek
  197004, -- Cliffside Wylderdrake: Spiked Legs
  197005, -- Cliffside Wylderdrake: Horned Nose
  197006, -- Cliffside Wylderdrake: Plated Nose
  197007, -- Cliffside Wylderdrake: Wide Stripes Pattern
  197008, -- Cliffside Wylderdrake: Narrow Stripes Pattern
  197009, -- Cliffside Wylderdrake: Scaled Pattern
  197010, -- Cliffside Wylderdrake: Red Scales
  197011, -- Cliffside Wylderdrake: Green Scales
  197012, -- Cliffside Wylderdrake: Blue Scales
  197013, -- Cliffside Wylderdrake: Black Scales
  197014, -- Cliffside Wylderdrake: White Scales
  197015, -- Cliffside Wylderdrake: Dark Skin Variation
  197016, -- Cliffside Wylderdrake: Maned Tail
  197017, -- Cliffside Wylderdrake: Large Tail Spikes
  197018, -- Cliffside Wylderdrake: Finned Tail
  197019, -- Cliffside Wylderdrake: Blunt Spiked Tail
  197020, -- Cliffside Wylderdrake: Spear Tail
  197021, -- Cliffside Wylderdrake: Spiked Club Tail
  197022, -- Cliffside Wylderdrake: Finned Neck
  197023, -- Cliffside Wylderdrake: Maned Neck
  197090, -- Highland Drake: Gold and Black Armor
  197091, -- Highland Drake: Silver and Blue Armor
  197093, -- Highland Drake: Silver and Purple Armor
  197094, -- Highland Drake: Gold and Red Armor
  197095, -- Highland Drake: Gold and White Armor
  197096, -- Highland Drake: Steel and Yellow Armor
  197097, -- Highland Drake: Spined Back
  197098, -- Highland Drake: Finned Back
  197099, -- Highland Drake: Armor
  197100, -- Highland Drake: Crested Brow
  197101, -- Highland Drake: Bushy Brow
  197102, -- Highland Drake: Horned Chin
  197103, -- Highland Drake: Maned Chin
  197104, -- Highland Drake: Tapered Chin
  197105, -- Highland Drake: Spined Chin
  197106, -- Highland Drake: Finned Head
  197107, -- Highland Drake: Triple Finned Head
  197108, -- Highland Drake: Spined Head
  197109, -- Highland Drake: Spiked Head
  197110, -- Highland Drake: Plated Head
  197111, -- Highland Drake: Maned Head
  197112, -- Highland Drake: Single Horned Head
  197113, -- Highland Drake: Swept Spiked Head
  197114, -- Highland Drake: Multi-Horned Head
  197115, -- Highland Drake: Thorned Jaw
  197116, -- Highland Drake: Ears
  197117, -- Highland Drake: Black Hair
  197118, -- Highland Drake: Brown Hair
  197119, -- Highland Drake: Helm
  197120, -- Highland Drake: Ornate Helm
  197121, -- Highland Drake: Tan Horns
  197122, -- Highland Drake: Heavy Horns
  197123, -- Highland Drake: Thorn Horns
  197124, -- Highland Drake: Swept Horns
  197125, -- Highland Drake: Coiled Horns
  197126, -- Highland Drake: Hooked Horns
  197127, -- Highland Drake: Grand Thorn Horns
  197128, -- Highland Drake: Curled Back Horns
  197129, -- Highland Drake: Sleek Horns
  197130, -- Highland Drake: Stag Horns
  197131, -- Highland Drake: Hairy Cheek
  197132, -- ERROR2
  197133, -- Highland Drake: Spined Cheek
  197134, -- Highland Drake: Spiked Legs
  197135, -- Highland Drake: Toothy Mouth
  197136, -- Highland Drake: Taperered Nose
  197137, -- Highland Drake: Spined Nose
  197138, -- Highland Drake: Striped Pattern
  197139, -- Highland Drake: Large Spotted Pattern
  197140, -- Highland Drake: Small Spotted Pattern
  197141, -- Highland Drake: Scaled Pattern
  197142, -- Highland Drake: Black Scales
  197143, -- Highland Drake: Green Scales
  197144, -- Highland Drake: Red Scales
  197145, -- Highland Drake: Bronze Scales
  197146, -- Highland Drake: White Scales
  197147, -- Highland Drake: Heavy Scales
  197148, -- Highland Drake: Vertical Finned Tail
  197149, -- Highland Drake: Club Tail
  197150, -- Highland Drake: Spiked Club Tail
  197151, -- Highland Drake: Spiked Tail
  197152, -- Highland Drake: Hooked Tail
  197153, -- Highland Drake: Bladed Tail
  197154, -- Highland Drake: Spined Neck
  197155, -- Highland Drake: Finned Neck
  197156, -- Highland Drake: Bronze and Green Armor
  197346, -- Renewed Proto-Drake: Gold and Black Armor
  197347, -- Renewed Proto-Drake: Silver and Blue Armor
  197348, -- Renewed Proto-Drake: Black and Red Armor
  197349, -- Renewed Proto-Drake: Gold and White Armor
  197350, -- Renewed Proto-Drake: Silver and Purple Armor
  197351, -- Renewed Proto-Drake: Gold and Red Armor
  197352, -- Renewed Proto-Drake: Steel and Yellow Armor
  197353, -- Renewed Proto-Drake: Bronze and Pink Armor
  197354, -- Renewed Proto-Drake: Horned Back
  197355, -- Renewed Proto-Drake: Thick Spined Jaw
  197356, -- Renewed Proto-Drake: Hairy Back
  197357, -- Renewed Proto-Drake: Armor
  197358, -- Renewed Proto-Drake: Curved Spiked Brow
  197359, -- Renewed Proto-Drake: Hairy Brow
  197360, -- Renewed Proto-Drake: Spined Brow
  197361, -- Renewed Proto-Drake: Spiked Crest
  197362, -- Renewed Proto-Drake: Spined Crest
  197363, -- Renewed Proto-Drake: Maned Crest
  197364, -- Renewed Proto-Drake: Short Spiked Crest
  197365, -- Renewed Proto-Drake: Finned Crest
  197366, -- Renewed Proto-Drake: Dual Horned Crest
  197367, -- Renewed Proto-Drake: Gray Hair
  197368, -- Renewed Proto-Drake: Blue Hair
  197369, -- Renewed Proto-Drake: Brown Hair
  197370, -- Renewed Proto-Drake: Red Hair
  197371, -- Renewed Proto-Drake: Green Hair
  197372, -- Renewed Proto-Drake: Purple Hair
  197373, -- ERROR2
  197374, -- Renewed Proto-Drake: Swept Horns
  197375, -- Renewed Proto-Drake: Curled Horns
  197376, -- Renewed Proto-Drake: Ears
  197377, -- Renewed Proto-Drake: Bovine Horns
  197378, -- Renewed Proto-Drake: Subtle Horns
  197379, -- Renewed Proto-Drake: Impaler Horns
  197380, -- Renewed Proto-Drake: Curved Horns
  197381, -- Renewed Proto-Drake: Gradient Horns
  197382, -- Renewed Proto-Drake: White Horns
  197383, -- Renewed Proto-Drake: Heavy Horns
  197384, -- Renewed Proto-Drake: Thick Spined Jaw
  197385, -- Renewed Proto-Drake: Horned Jaw
  197386, -- Renewed Proto-Drake: Spiked Jaw
  197387, -- Renewed Proto-Drake: Thin Spined Jaw
  197388, -- Renewed Proto-Drake: Finned Jaw
  197389, -- Renewed Proto-Drake: Green Scales
  197390, -- Renewed Proto-Drake: Blue Scales
  197391, -- Renewed Proto-Drake: Bronze Scales
  197392, -- Renewed Proto-Drake: Black Scales
  197393, -- Renewed Proto-Drake: White Scales
  197394, -- Renewed Proto-Drake: Predator Pattern
  197395, -- Renewed Proto-Drake: Harrier Pattern
  197396, -- Renewed Proto-Drake: Skyterror Pattern
  197397, -- Renewed Proto-Drake: Heavy Scales
  197398, -- Renewed Proto-Drake: Snub Snout
  197399, -- Renewed Proto-Drake: Razor Snout
  197400, -- Renewed Proto-Drake: Shark Snout
  197401, -- Renewed Proto-Drake: Beaked Snout
  197402, -- Renewed Proto-Drake: Spiked Club Tail
  197403, -- Renewed Proto-Drake: Club Tail
  197404, -- Renewed Proto-Drake: Finned Tail
  197405, -- Renewed Proto-Drake: Maned Tail
  197406, -- Renewed Proto-Drake: Spined Tail
  197407, -- Renewed Proto-Drake: Spiked Throat
  197408, -- Renewed Proto-Drake: Finned Throat
  197577, -- Windborne Velocidrake: Bronze and Green Armor
  197578, -- Windborne Velocidrake: Silver and Blue Armor
  197579, -- Windborne Velocidrake: Steel and Orange Armor
  197580, -- Windborne Velocidrake: Gold and Red Armor
  197581, -- Windborne Velocidrake: Silver and Purple Armor
  197582, -- Windborne Velocidrake: White and Pink Armor
  197583, -- Windborne Velocidrake: Exposed Finned Back
  197584, -- Windborne Velocidrake: Finned Back
  197585, -- Windborne Velocidrake: Maned Back
  197586, -- Windborne Velocidrake: Spiked Back
  197587, -- Windborne Velocidrake: Feathered Back
  197588, -- Windborne Velocidrake: Armor
  197589, -- Windborne Velocidrake: Large Head Fin
  197590, -- Windborne Velocidrake: Small Head Fin
  197591, -- Windborne Velocidrake: Hairy Head
  197592, -- Windborne Velocidrake: Spined Head
  197593, -- Windborne Velocidrake: Feathery Head
  197594, -- Windborne Velocidrake: Small Ears
  197595, -- Windborne Velocidrake: Finned Ears
  197596, -- Windborne Velocidrake: Horned Jaw
  197597, -- Windborne Velocidrake: Black Fur
  197598, -- Windborne Velocidrake: Gray Hair
  197599, -- Windborne Velocidrake: Red Hair
  197600, -- Windborne Velocidrake: Helm
  197601, -- Windborne Velocidrake: Wavy Horns
  197602, -- Windborne Velocidrake: Cluster Horns
  197603, -- Windborne Velocidrake: Curved Horns
  197604, -- Windborne Velocidrake: Ox Horns
  197605, -- Windborne Velocidrake: Curled Horns
  197606, -- Windborne Velocidrake: Swept Horns
  197607, -- Windborne Velocidrake: Split Horns
  197608, -- Windborne Velocidrake: Gray Horns
  197609, -- Windborne Velocidrake: White Horns
  197610, -- Windborne Velocidrake: Yellow Horns
  197611, -- Windborne Velocidrake: Black Scales
  197612, -- Windborne Velocidrake: Blue Scales
  197613, -- Windborne Velocidrake: Bronze Scales
  197614, -- Windborne Velocidrake: Red Scales
  197615, -- Windborne Velocidrake: Teal Scales
  197616, -- Windborne Velocidrake: White Scales
  197617, -- Windborne Velocidrake: Heavy Scales
  197618, -- Windborne Velocidrake: Long Snout
  197619, -- Windborne Velocidrake: Hooked Snout
  197620, -- Windborne Velocidrake: Beaked Snout
  197621, -- Windborne Velocidrake: Exposed Finned Tail
  197622, -- Windborne Velocidrake: Finned Tail
  197623, -- Windborne Velocidrake: Spiked Tail
  197624, -- Windborne Velocidrake: Club Tail
  197625, -- Windborne Velocidrake: Feathery Tail
  197626, -- Windborne Velocidrake: Exposed Finned Neck
  197627, -- Windborne Velocidrake: Finned Neck
  197628, -- Windborne Velocidrake: Plated Neck
  197629, -- Windborne Velocidrake: Spiked Neck
  197630, -- Windborne Velocidrake: Feathered Neck
  197634, -- Windborne Velocidrake: Windswept Pattern
  197635, -- Windborne Velocidrake: Reaver Pattern
  197636, -- Windborne Velocidrake: Shrieker Pattern
  199074, -- Studies of Arcane Magic
  201790, -- Renewed Proto-Drake: Embodiment of the Storm-Eater
  201792, -- Highland Drake: Embodiment of the Crimson Gladiator
}

-- Fortune Cards
local FortuneCards_IDs = {
  194829, -- Fated Fortune Card
  199114, -- Fated Fortune Card
  199116, -- Fated Fortune Card
  199117, -- Fated Fortune Card
  199118, -- Fated Fortune Card
  199119, -- Fated Fortune Card
  199120, -- Fated Fortune Card
  199121, -- Fated Fortune Card
  199123, -- Fated Fortune Card
  199124, -- Fated Fortune Card
  199125, -- Fated Fortune Card
  199126, -- Fated Fortune Card
  199127, -- Fated Fortune Card
  199129, -- Fated Fortune Card
  199130, -- Fated Fortune Card
  199131, -- Fated Fortune Card
  199132, -- Fated Fortune Card
  199133, -- Fated Fortune Card
  199134, -- Fated Fortune Card
  199135, -- Fated Fortune Card
  199136, -- Fated Fortune Card
  199137, -- Fated Fortune Card
  199138, -- Fated Fortune Card
  199139, -- Fated Fortune Card
  199140, -- Fated Fortune Card
  199141, -- Fated Fortune Card
  199142, -- Fated Fortune Card
  199143, -- Fated Fortune Card
  199144, -- Fated Fortune Card
  199145, -- Fated Fortune Card
  199146, -- Fated Fortune Card
  199147, -- Fated Fortune Card
  199148, -- Fated Fortune Card
  199149, -- Fated Fortune Card
  199150, -- Fated Fortune Card
  199151, -- Fated Fortune Card
  199152, -- Fated Fortune Card
  199153, -- Fated Fortune Card
  199154, -- Fated Fortune Card
  199155, -- Fated Fortune Card
  199156, -- Fated Fortune Card
  199157, -- Fated Fortune Card
  199158, -- Fated Fortune Card
  199159, -- Fated Fortune Card
  199160, -- Fated Fortune Card
  199161, -- Fated Fortune Card
  199162, -- Fated Fortune Card
  199163, -- Fated Fortune Card
  199164, -- Fated Fortune Card
  199165, -- Fated Fortune Card
  199166, -- Fated Fortune Card
  199167, -- Fated Fortune Card
  199168, -- Fated Fortune Card
  199169, -- Fated Fortune Card
  199170, -- Fated Fortune Card
}

-- Reputation Items
local ReputationItems_IDs = {
  191251, -- Key Fragments
  191264, -- Restored Obsidian Key
  192055, -- Dragon Isles Artifact
  193201, -- Key Framing
  199906, -- Titan Relic
  200071, -- Sacred Tuskarr Totem
  200093, -- Centaur Hunting Trophy
  200224, -- Mark of Sargha
  200285, -- Dragonscale Expedition Insignia
  200287, -- Iskaara Tuskarr Insignia
  200288, -- Maruuk Centaur Insignia
  200289, -- Valdrakken Accord Insignia
  200443, -- Dragon Isles Artifact
  200447, -- Centaur Hunting Trophy
  200450, -- Titan Relic
  200452, -- Dragonscale Expedition Insignia
  200453, -- Iskaara Tuskarr Insignia
  200454, -- Maruuk Centaur Insignia
  200455, -- Valdrakken Accord Insignia
  201411, -- Ancient Vault Artifact
  201779, -- Merithra's Blessing
  201781, -- Memory of Tyr
  201782, -- Tyr's Blessing
  201783, -- Tutaqan's Commendation
  201921, -- Dragonscale Expedition Insignia
  201922, -- Iskaara Tuskarr Insignia
  201923, -- Maruuk Centaur Insignia
  201924, -- Valdrakken Accord Insignia
  201991, -- Sargha's Signet
  202091, -- Dragonscale Expedition Insignia
  202092, -- Iskaara Tuskarr Insignia
  202093, -- Valdrakken Accord Insignia
  202094, -- Maruuk Centaur Insignia
}

-- Treasure Maps
local TreasureMaps_IDs = {
  194540, -- Nokhud Armorer's Notes
  198843, -- Emerald Gardens Explorer's Notes
  198852, -- Bear Termination Orders
  198854, -- Archeologist Artifact Notes
  199061, -- A Guide to Rare Fish
  199062, -- Ruby Gem Cluster Map
  199065, -- Sorrowful Letter
  199066, -- Letter of Caution
  199067, -- Precious Plans
  199068, -- Time-Lost Memo
  200738, -- Onyx Gem Cluster Map
}

-- Treasure Sacks
local TreasureSacks_IDs = {
  199341, -- Regurgitated Sac of Swog Treasures
  199342, -- Weighted Sac of Swog Treasures
  199343, -- ERROR1
  202102, -- Immaculate Sac of Swog Treasures
  202103, -- ERROR1
  202104, -- ERROR1
}

-- PreEvent Currency
local PreEventCurrency_IDs = {
  199211, -- Primeval Essence
  199836, -- Dimmed Primeval Fire
  199837, -- Dimmed Primeval Earth
  199838, -- Dimmed Primeval Storm
  199839, -- Dimmed Primeval Water
}

-- PreEvent Gear
local PreEventGear_IDs = {
  199348, -- Cloudburst Robes
  199349, -- Cloudburst Slippers
  199350, -- Cloudburst Mitts
  199351, -- Cloudburst Hood
  199352, -- Cloudburst Breeches
  199353, -- Cloudburst Mantle
  199354, -- Cloudburst Sash
  199355, -- Cloudburst Bindings
  199356, -- Dust Devil Raiment
  199357, -- Dust Devil Treads
  199358, -- Dust Devil Gloves
  199359, -- Dust Devil Mask
  199360, -- Dust Devil Leggings
  199361, -- Dust Devil Epaulets
  199362, -- Dust Devil Cincture
  199363, -- Dust Devil Wristbands
  199364, -- Cyclonic Chainmail
  199365, -- Cyclonic Striders
  199366, -- Cyclonic Gauntlets
  199367, -- Cyclonic Cowl
  199368, -- Cyclonic Kilt
  199369, -- Cyclonic Spaulders
  199370, -- Cyclonic Cinch
  199371, -- Cyclonic Bracers
  199372, -- Firestorm Chestplate
  199373, -- Firestorm Stompers
  199374, -- Firestorm Crushers
  199375, -- Firestorm Greathelm
  199376, -- Firestorm Greaves
  199377, -- Firestorm Pauldrons
  199378, -- Firestorm Girdle
  199379, -- Firestorm Vambraces
  199380, -- Cyclonic Drape
  199381, -- Seal of Elemental Disasters
  199382, -- Catastrophe Signet
  199383, -- Torc of Calamities
  199384, -- Cloudburst Wrap
  199385, -- Dust Devil Cloak
  199386, -- Firestorm Cape
  199399, -- Galerider Poleaxe
  199400, -- Squallbreaker Greatsword
  199401, -- Stormbender Scroll
  199402, -- Galepiercer Ballista
  199403, -- Stormbender Maul
  199404, -- Squallbreaker Shield
  199405, -- Stormbender Rod
  199406, -- Galerider Mallet
  199407, -- Galerider Shank
  199408, -- Squallbreaker Longblade
  199409, -- Stormbender Saber
  199416, -- Galerider Crescent
  199555, -- Versatile Storm Lure
  199645, -- Storm Hunter's Insignia
}

-- Alchemy Flasks
local AlchemyFlasks_IDs = {
  191474, -- Draconic Vial
  191475, -- Draconic Vial
  191476, -- Draconic Vial
  198265, -- Portable Alchemist's Lab Bench
}

-- Cloth
local Cloth_IDs = {
  192095, -- Spool of Wilderthread
  192096, -- Spool of Wilderthread
  192097, -- Spool of Wilderthread
  193050, -- Tattered Wildercloth
  193053, -- Contoured Fowlfeather
  193922, -- Wildercloth
  193923, -- Decayed Wildercloth
  193924, -- Frostbitten Wildercloth
  193925, -- Singed Wildercloth
  193926, -- Wildercloth Bolt
  193927, -- Wildercloth Bolt
  193928, -- Wildercloth Bolt
  193929, -- Vibrant Wildercloth Bolt
  193930, -- Vibrant Wildercloth Bolt
  193931, -- Vibrant Wildercloth Bolt
  193932, -- Infurious Wildercloth Bolt
  193933, -- Infurious Wildercloth Bolt
  193934, -- Infurious Wildercloth Bolt
  193935, -- Chronocloth Bolt
  193936, -- Chronocloth Bolt
  193937, -- Chronocloth Bolt
  193938, -- Azureweave Bolt
  193939, -- Azureweave Bolt
  193940, -- Azureweave Bolt
}

-- Cooking
local Cooking_IDs = {
  194730, -- Scalebelly Mackerel
  194966, -- Thousandbite Piranha
  194967, -- Aileron Seamoth
  194968, -- Cerulean Spinefish
  194969, -- Temporal Dragonhead
  194970, -- Islefin Dorado
  197741, -- Maybe Meat
  197742, -- Ribbed Mollusk Meat
  197743, -- Waterfowl Filet
  197744, -- Hornswog Hunk
  197745, -- Basilisk Eggs
  197746, -- Bruffalon Flank
  197747, -- Mighty Mammoth Ribs
  197748, -- Burly Bear Haunch
  197749, -- Ohn'ahran Potato
  197750, -- Three-Cheese Blend
  197751, -- Pastry Packets
  197752, -- Conveniently Packaged Ingredients
  197753, -- Thaldraszian Cocoa Powder
  197754, -- Salt Deposit
  197755, -- Lava Beetle
  197756, -- Pebbled Rock Salts
  197757, -- Assorted Exotic Spices
  198395, -- Dull Spined Clam
  199063, -- Salted Fish Scraps
  199100, -- Peppersmelt
  199101, -- Dried Wyldermane Kelp
  199102, -- Hunk o' Blubber
  199103, -- Nappa's Famous Tea
  199104, -- Piping-Hot Orca Milk
  199105, -- Ancheevy
  199106, -- Tiny Leviathan Bone
  199205, -- Manasucker
  199207, -- Iceback Sculpin
  199208, -- Grungle
  199212, -- Clubfish
  199213, -- Lakkamuk Blenny
  199344, -- Magma Thresher
  199345, -- Rimefin Tuna
  199346, -- Rotten Rimefin Tuna
  199832, -- Smoked Seaviper
  199833, -- Dragonhead Eel
  199834, -- Pulpy Seagrass
  199835, -- Torga's Braid
  200061, -- Prismatic Leaper
  200074, -- Frosted Rimefin Tuna
}

-- Enchanting
local Enchanting_IDs = {
  193057, -- 10.0 Placeholder Enchanting Crystal
  194123, -- Chromatic Dust
  194124, -- Vibrant Shard
  200113, -- Resonant Crystal
  201584, -- Serevite Rod
}

-- Enchanting - Insight of the Blue
local EnchantingInsightoftheBlue_IDs = {
  200939, -- Chromatic Pocketwatch
  200940, -- Everflowing Inkwell
  200941, -- Seal of Order
  200942, -- Vibrant Emulsion
  200943, -- Whispering Band
  200945, -- Valiant Hammer
  200946, -- Thunderous Blade
  200947, -- Carving of Awakening
}

-- Engineering
local Engineering_IDs = {
  198183, -- Handful of Serevite Bolts
  198184, -- Handful of Serevite Bolts
  198185, -- Handful of Serevite Bolts
  198186, -- Shock-Spring Coil
  198187, -- Shock-Spring Coil
  198188, -- Shock-Spring Coil
  198189, -- Everburning Blasting Powder
  198190, -- Everburning Blasting Powder
  198191, -- Everburning Blasting Powder
  198192, -- Greased-Up Gears
  198193, -- Greased-Up Gears
  198194, -- Greased-Up Gears
  198195, -- Arclight Capacitor
  198196, -- Arclight Capacitor
  198197, -- Arclight Capacitor
  198198, -- Reinforced Machine Chassis
  198199, -- Reinforced Machine Chassis
  198200, -- Reinforced Machine Chassis
  198201, -- Assorted Safety Fuses
  198202, -- Assorted Safety Fuses
  198203, -- Assorted Safety Fuses
  201832, -- Smudged Lens
}

-- Fishing Lures
local FishingLures_IDs = {
  193893, -- Scalebelly Mackerel Lure
  193894, -- Thousandbite Piranha Lure
  193895, -- Temporal Dragonhead Lure
  193896, -- Cerulean Spinefish Lure
  198401, -- Aileron Seamoth Lure
  198403, -- Islefin Dorado Lure
}

-- Herbs
local Herbs_IDs = {
  191460, -- Hochenblume
  191461, -- Hochenblume
  191462, -- Hochenblume
  191464, -- Saxifrage
  191465, -- Saxifrage
  191466, -- Saxifrage
  191467, -- Bubble Poppy
  191468, -- Bubble Poppy
  191469, -- Bubble Poppy
  191470, -- Writhebark
  191471, -- Writhebark
  191472, -- Writhebark
}

-- Herbs - Seeds
local HerbsSeeds_IDs = {
  200506, -- Roused Seedling
  200507, -- Decayed Roused Seedling
  200508, -- Propagating Roused Seedling
  200509, -- Agitated Roused Seedling
}

-- Inscription
local Inscription_IDs = {
  194751, -- Blazing Ink
  194752, -- Blazing Ink
  194754, -- Cosmic Ink
  194755, -- Cosmic Ink
  194756, -- Cosmic Ink
  194758, -- Flourishing Ink
  194760, -- Burnished Ink
  194761, -- Burnished Ink
  194767, -- Chilled Rune
  194768, -- Chilled Rune
  194784, -- Glittering Parchment
  194846, -- Blazing Ink
  194850, -- Flourishing Ink
  194852, -- Flourishing Ink
  194855, -- Burnished Ink
  194856, -- Serene Ink
  194857, -- Serene Ink
  194858, -- Serene Ink
  194859, -- Chilled Rune
  194862, -- Runed Writhebark
  194863, -- Runed Writhebark
  194864, -- Runed Writhebark
  198412, -- Serene Pigment
  198413, -- Serene Pigment
  198414, -- Serene Pigment
  198415, -- Flourishing Pigment
  198416, -- Flourishing Pigment
  198417, -- Flourishing Pigment
  198418, -- Blazing Pigment
  198419, -- Blazing Pigment
  198420, -- Blazing Pigment
  198421, -- Shimmering Pigment
  198422, -- Shimmering Pigment
  198423, -- Shimmering Pigment
}

-- Jewelcrafting
local Jewelcrafting_IDs = {
  192833, -- Misshapen Filigree
  192834, -- Shimmering Clasp
  192835, -- Shimmering Clasp
  192836, -- Shimmering Clasp
  192837, -- Queen's Ruby
  192838, -- Queen's Ruby
  192839, -- Queen's Ruby
  192840, -- Mystic Sapphire
  192841, -- Mystic Sapphire
  192842, -- Mystic Sapphire
  192843, -- Vibrant Emerald
  192844, -- Vibrant Emerald
  192845, -- Vibrant Emerald
  192846, -- Sundered Onyx
  192847, -- Sundered Onyx
  192848, -- Sundered Onyx
  192849, -- Eternity Amber
  192850, -- Eternity Amber
  192851, -- Eternity Amber
  192852, -- Alexstraszite
  192853, -- Alexstraszite
  192855, -- Alexstraszite
  192856, -- Malygite
  192857, -- Malygite
  192858, -- Malygite
  192859, -- Ysemerald
  192860, -- Ysemerald
  192861, -- Ysemerald
  192862, -- Neltharite
  192863, -- Neltharite
  192865, -- Neltharite
  192866, -- Nozdorite
  192867, -- Nozdorite
  192868, -- Nozdorite
  192869, -- Illimited Diamond
  192870, -- Illimited Diamond
  192871, -- Illimited Diamond
  192872, -- Fractured Glass
  192876, -- Frameless Lens
  192877, -- Frameless Lens
  192878, -- Frameless Lens
  192880, -- Crumbled Stone
  192883, -- Glossy Stone
  192884, -- Glossy Stone
  192885, -- Glossy Stone
  192888, -- Queen's Gift
  192889, -- Dreamer's Vision
  192890, -- Keeper's Glory
  192891, -- Earthwarden's Prize
  192892, -- Timewatcher's Patience
  192893, -- Jeweled Dragon's Heart
  192894, -- Blotting Sand
  192895, -- Blotting Sand
  192896, -- Blotting Sand
  192897, -- Pounce
  192898, -- Pounce
  192899, -- Pounce
  193029, -- Projection Prism
  193030, -- Projection Prism
  193031, -- Projection Prism
  193368, -- Silken Gemdust
  193369, -- Silken Gemdust
  193370, -- Silken Gemdust
  198397, -- Rainbow Pearl
  200156, -- Amethyzarite Geode
  202048, -- Queen's Gift
  202049, -- Dreamer's Vision
  202050, -- Keeper's Glory
  202051, -- Earthwarden's Prize
  202052, -- Timewatcher's Patience
  202053, -- ERROR1
  202054, -- Queen's Gift
  202055, -- Dreamer's Vision
  202056, -- Keeper's Glory
  202057, -- Earthwarden's Prize
  202058, -- Timewatcher's Patience
  202059, -- ERROR1
}

-- Leather
local Leather_IDs = {
  193208, -- Resilient Leather
  193210, -- Resilient Leather
  193211, -- Resilient Leather
  193213, -- Adamant Scales
  193214, -- Adamant Scales
  193215, -- Adamant Scales
  193216, -- Dense Hide
  193217, -- Dense Hide
  193218, -- Dense Hide
  193222, -- Lustrous Scaled Hide
  193223, -- Lustrous Scaled Hide
  193224, -- Lustrous Scaled Hide
  193226, -- Stonecrust Hide
  193227, -- Stonecrust Hide
  193228, -- Stonecrust Hide
  193229, -- Mireslush Hide
  193230, -- Mireslush Hide
  193231, -- Mireslush Hide
  193232, -- Deathchill Hide
  193233, -- Deathchill Hide
  193234, -- Deathchill Hide
  193236, -- Infurious Hide
  193237, -- Infurious Hide
  193238, -- Infurious Hide
  193239, -- Drygrate Scales
  193240, -- Drygrate Scales
  193241, -- Drygrate Scales
  193242, -- Earthshine Scales
  193243, -- Earthshine Scales
  193244, -- Earthshine Scales
  193245, -- Frostbite Scales
  193246, -- Frostbite Scales
  193247, -- Frostbite Scales
  193248, -- Infurious Scales
  193249, -- Infurious Scales
  193250, -- Infurious Scales
  193251, -- Crystalspine Fur
  193252, -- Salamanther Scales
  193253, -- Cacophonous Thunderscale
  193254, -- Rockfang Leather
  193255, -- Pristine Vorquin Horn
  193256, -- Windsong Plumage
  193258, -- Fire-Infused Hide
  193259, -- Flawless Proto Dragon Scale
  193261, -- Bite-Sized Morsel
  193262, -- Exceptional Morsel
  197735, -- Finished Prototype Explorer's Barding
  197736, -- Finished Prototype Regal Barding
}

-- Leather - Bait
local LeatherBait_IDs = {
  193906, -- Elusive Creature Bait
  198404, -- Bottled Pheromones
  198804, -- Frost-Infused Creature Bait
  198805, -- Earth-Infused Creature Bait
  198806, -- Decay-Infused Creature Bait
  198807, -- Titan-Infused Creature Bait
}

-- Mining
local Mining_IDs = {
  188658, -- Draconium Ore
  189143, -- Draconium Ore
  189541, -- Primal Molten Alloy
  189542, -- Primal Molten Alloy
  189543, -- Primal Molten Alloy
  190311, -- Draconium Ore
  190312, -- Khaz'gorite Ore
  190313, -- Khaz'gorite Ore
  190314, -- Khaz'gorite Ore
  190394, -- Serevite Ore
  190395, -- Serevite Ore
  190396, -- Serevite Ore
  190452, -- Primal Flux
  190530, -- Frostfire Alloy
  190531, -- Frostfire Alloy
  190532, -- Frostfire Alloy
  190533, -- Obsidian Seared Alloy
  190534, -- Obsidian Seared Alloy
  190535, -- Obsidian Seared Alloy
  190536, -- Infurious Alloy
  190537, -- Infurious Alloy
  190538, -- Infurious Alloy
  194545, -- Prismatic Ore
}

local function converttohex(rgb)
  return string.format("%02x%02x%02x", rgb.r * 255, rgb.g * 255, rgb.b * 255)
end

local function converttorgb(hex, as_table)
  if as_table then
    return {
      r = tonumber("0x" .. strsub(hex, 1, 2)) / 255,
      g = tonumber("0x" .. strsub(hex, 3, 4)) / 255,
      b = tonumber("0x" .. strsub(hex, 5, 6)) / 255,
    }
  else
    -- as 3 values
    return tonumber("0x" .. hex:sub(1, 2)) / 255,
      tonumber("0x" .. hex:sub(3, 4)) / 255,
      tonumber("0x" .. hex:sub(5, 6)) / 255
  end
end


local function formatBagTitle(self, title, hex)
  local prefix = ""
  if self.db.profile.prefixCategories then
    if self.db.profile.prefixCategories == "!CUSTOM" then
      prefix = self.db.profile.customPrefix
    else
      prefix = self.db.profile.prefixCategories
    end
  end
  if self.db.profile.coloredPrefix then
    prefix = "|cff" .. converttohex(self.db.profile.color.prefix) .. prefix .. "|r"
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  else
    if self.db.profile.coloredCategories then
      return prefix .. "|cff" .. hex .. title .. "|r"
    else
      return prefix .. title
    end
  end
end

local function MatchIDs_Init(self)
  wipe(Result)

  if self.db.profile.moveMergedAchievementsUnlockables then
    Result[formatBagTitle(
      self,
      L["Achievements & Unlockables"],
      converttohex(self.db.profile.color.mergedAchievementsUnlockables)
    )] =
      AddToSet(
        HonorOurAncestors_IDs,
        LizisReinsMount_IDs,
        MagmashellMount_IDs,
        OttoMount_IDs,
        ScrappyWorldsnailMount_IDs,
        TemperamentalSkyclawMount_IDs,
        TetrachromancerAchievement_IDs
      )
  else
    if self.db.profile.moveHonorOurAncestors then
      Result[formatBagTitle(self, L["Honor Our Ancestors"], converttohex(self.db.profile.color.HonorOurAncestors))] =
        AddToSet(HonorOurAncestors_IDs)
    end
    if self.db.profile.moveLizisReinsMount then
      Result[formatBagTitle(self, L["Lizis Reins (Mount)"], converttohex(self.db.profile.color.LizisReinsMount))] =
        AddToSet(LizisReinsMount_IDs)
    end
    if self.db.profile.moveMagmashellMount then
      Result[formatBagTitle(self, L["Magmashell (Mount)"], converttohex(self.db.profile.color.MagmashellMount))] =
        AddToSet(MagmashellMount_IDs)
    end
    if self.db.profile.moveOttoMount then
      Result[formatBagTitle(self, L["Otto (Mount)"], converttohex(self.db.profile.color.OttoMount))] =
        AddToSet(OttoMount_IDs)
    end
    if self.db.profile.moveScrappyWorldsnailMount then
      Result[formatBagTitle(
        self,
        L["Scrappy Worldsnail (Mount)"],
        converttohex(self.db.profile.color.ScrappyWorldsnailMount)
      )] =
        AddToSet(ScrappyWorldsnailMount_IDs)
    end
    if self.db.profile.moveTemperamentalSkyclawMount then
      Result[formatBagTitle(
        self,
        L["Temperamental Skyclaw (Mount)"],
        converttohex(self.db.profile.color.TemperamentalSkyclawMount)
      )] =
        AddToSet(TemperamentalSkyclawMount_IDs)
    end
    if self.db.profile.moveTetrachromancerAchievement then
      Result[formatBagTitle(
        self,
        L["Tetrachromancer (Achievement)"],
        converttohex(self.db.profile.color.TetrachromancerAchievement)
      )] =
        AddToSet(TetrachromancerAchievement_IDs)
    end
  end
  if self.db.profile.moveMergedConsumables then
    Result[formatBagTitle(self, L["Consumables"], converttohex(self.db.profile.color.mergedConsumables))] = AddToSet(
      Bandages_IDs,
      Cauldrons_IDs,
      Contracts_IDs,
      CraftingPotions_IDs,
      Food_IDs,
      Incense_IDs,
      Phials_IDs,
      Potions_IDs,
      RubyFeast_IDs,
      Runes_IDs,
      Statues_IDs,
      Tools_IDs
    )
  else
    if self.db.profile.moveBandages then
      Result[formatBagTitle(self, L["Bandages"], converttohex(self.db.profile.color.Bandages))] = AddToSet(Bandages_IDs)
    end
    if self.db.profile.moveCauldrons then
      Result[formatBagTitle(self, L["Cauldrons"], converttohex(self.db.profile.color.Cauldrons))] =
        AddToSet(Cauldrons_IDs)
    end
    if self.db.profile.moveContracts then
      Result[formatBagTitle(self, L["Contracts"], converttohex(self.db.profile.color.Contracts))] =
        AddToSet(Contracts_IDs)
    end
    if self.db.profile.moveCraftingPotions then
      Result[formatBagTitle(self, L["Crafting Potions"], converttohex(self.db.profile.color.CraftingPotions))] =
        AddToSet(CraftingPotions_IDs)
    end
    if self.db.profile.moveFood then
      Result[formatBagTitle(self, L["Food"], converttohex(self.db.profile.color.Food))] = AddToSet(Food_IDs)
    end
    if self.db.profile.moveIncense then
      Result[formatBagTitle(self, L["Incense"], converttohex(self.db.profile.color.Incense))] = AddToSet(Incense_IDs)
    end
    if self.db.profile.movePhials then
      Result[formatBagTitle(self, L["Phials"], converttohex(self.db.profile.color.Phials))] = AddToSet(Phials_IDs)
    end
    if self.db.profile.movePotions then
      Result[formatBagTitle(self, L["Potions"], converttohex(self.db.profile.color.Potions))] = AddToSet(Potions_IDs)
    end
    if self.db.profile.moveRubyFeast then
      Result[formatBagTitle(self, L["Ruby Feast"], converttohex(self.db.profile.color.RubyFeast))] =
        AddToSet(RubyFeast_IDs)
    end
    if self.db.profile.moveRunes then
      Result[formatBagTitle(self, L["Runes"], converttohex(self.db.profile.color.Runes))] = AddToSet(Runes_IDs)
    end
    if self.db.profile.moveStatues then
      Result[formatBagTitle(self, L["Statues"], converttohex(self.db.profile.color.Statues))] = AddToSet(Statues_IDs)
    end
    if self.db.profile.moveTools then
      Result[formatBagTitle(self, L["Tools"], converttohex(self.db.profile.color.Tools))] = AddToSet(Tools_IDs)
    end
  end
  if self.db.profile.moveMergedElementalTradeGoods then
    Result[formatBagTitle(
      self,
      L["Elemental Trade Goods"],
      converttohex(self.db.profile.color.mergedElementalTradeGoods)
    )] =
      AddToSet(AwakenedElementals_IDs, RousingElementals_IDs)
  else
    if self.db.profile.moveAwakenedElementals then
      Result[formatBagTitle(self, L["Awakened Elementals"], converttohex(self.db.profile.color.AwakenedElementals))] =
        AddToSet(AwakenedElementals_IDs)
    end
    if self.db.profile.moveRousingElementals then
      Result[formatBagTitle(self, L["Rousing Elementals"], converttohex(self.db.profile.color.RousingElementals))] =
        AddToSet(RousingElementals_IDs)
    end
  end
  if self.db.profile.moveGeneralCraftingReagents then
    Result[formatBagTitle(
      self,
      L["General Crafting Reagents"],
      converttohex(self.db.profile.color.GeneralCraftingReagents)
    )] =
      AddToSet(GeneralCraftingReagents_IDs)
  end
  if self.db.profile.moveProfessionGear then
    Result[formatBagTitle(self, L["Profession Gear"], converttohex(self.db.profile.color.ProfessionGear))] =
      AddToSet(ProfessionGear_IDs)
  end
  if self.db.profile.moveProfessionKnowledge then
    Result[formatBagTitle(self, L["Profession Knowledge"], converttohex(self.db.profile.color.ProfessionKnowledge))] =
      AddToSet(ProfessionKnowledge_IDs)
  end
  if self.db.profile.moveDarkmoonCards then
    Result[formatBagTitle(self, L["Darkmoon Cards"], converttohex(self.db.profile.color.DarkmoonCards))] =
      AddToSet(DarkmoonCards_IDs)
  end
  if self.db.profile.moveDrakewatcherManuscripts then
    Result[formatBagTitle(
      self,
      L["Drakewatcher Manuscripts"],
      converttohex(self.db.profile.color.DrakewatcherManuscripts)
    )] =
      AddToSet(DrakewatcherManuscripts_IDs)
  end
  if self.db.profile.moveFortuneCards then
    Result[formatBagTitle(self, L["Fortune Cards"], converttohex(self.db.profile.color.FortuneCards))] =
      AddToSet(FortuneCards_IDs)
  end
  if self.db.profile.moveReputationItems then
    Result[formatBagTitle(self, L["Reputation Items"], converttohex(self.db.profile.color.ReputationItems))] =
      AddToSet(ReputationItems_IDs)
  end
  if self.db.profile.moveTreasureMaps then
    Result[formatBagTitle(self, L["Treasure Maps"], converttohex(self.db.profile.color.TreasureMaps))] =
      AddToSet(TreasureMaps_IDs)
  end
  if self.db.profile.moveTreasureSacks then
    Result[formatBagTitle(self, L["Treasure Sacks"], converttohex(self.db.profile.color.TreasureSacks))] =
      AddToSet(TreasureSacks_IDs)
  end
  if self.db.profile.moveMergedPreEvent then
    Result[formatBagTitle(self, L["PreEvent"], converttohex(self.db.profile.color.mergedPreEvent))] =
      AddToSet(PreEventCurrency_IDs, PreEventGear_IDs)
  else
    if self.db.profile.movePreEventCurrency then
      Result[formatBagTitle(self, L["PreEvent Currency"], converttohex(self.db.profile.color.PreEventCurrency))] =
        AddToSet(PreEventCurrency_IDs)
    end
    if self.db.profile.movePreEventGear then
      Result[formatBagTitle(self, L["PreEvent Gear"], converttohex(self.db.profile.color.PreEventGear))] =
        AddToSet(PreEventGear_IDs)
    end
  end
  if self.db.profile.moveMergedProfessions then
    Result[formatBagTitle(self, L["Professions"], converttohex(self.db.profile.color.mergedProfessions))] = AddToSet(
      AlchemyFlasks_IDs,
      Cloth_IDs,
      Cooking_IDs,
      Enchanting_IDs,
      EnchantingInsightoftheBlue_IDs,
      Engineering_IDs,
      FishingLures_IDs,
      Herbs_IDs,
      HerbsSeeds_IDs,
      Inscription_IDs,
      Jewelcrafting_IDs,
      Leather_IDs,
      LeatherBait_IDs,
      Mining_IDs
    )
  else
    if self.db.profile.moveAlchemyFlasks then
      Result[formatBagTitle(self, L["Alchemy Flasks"], converttohex(self.db.profile.color.AlchemyFlasks))] =
        AddToSet(AlchemyFlasks_IDs)
    end
    if self.db.profile.moveCloth then
      Result[formatBagTitle(self, L["Cloth"], converttohex(self.db.profile.color.Cloth))] = AddToSet(Cloth_IDs)
    end
    if self.db.profile.moveCooking then
      Result[formatBagTitle(self, L["Cooking"], converttohex(self.db.profile.color.Cooking))] = AddToSet(Cooking_IDs)
    end
    if self.db.profile.moveEnchanting then
      Result[formatBagTitle(self, L["Enchanting"], converttohex(self.db.profile.color.Enchanting))] =
        AddToSet(Enchanting_IDs)
    end
    if self.db.profile.moveEnchantingInsightoftheBlue then
      Result[formatBagTitle(
        self,
        L["Enchanting - Insight of the Blue"],
        converttohex(self.db.profile.color.EnchantingInsightoftheBlue)
      )] =
        AddToSet(EnchantingInsightoftheBlue_IDs)
    end
    if self.db.profile.moveEngineering then
      Result[formatBagTitle(self, L["Engineering"], converttohex(self.db.profile.color.Engineering))] =
        AddToSet(Engineering_IDs)
    end
    if self.db.profile.moveFishingLures then
      Result[formatBagTitle(self, L["Fishing Lures"], converttohex(self.db.profile.color.FishingLures))] =
        AddToSet(FishingLures_IDs)
    end
    if self.db.profile.moveHerbs then
      Result[formatBagTitle(self, L["Herbs"], converttohex(self.db.profile.color.Herbs))] = AddToSet(Herbs_IDs)
    end
    if self.db.profile.moveHerbsSeeds then
      Result[formatBagTitle(self, L["Herbs - Seeds"], converttohex(self.db.profile.color.HerbsSeeds))] =
        AddToSet(HerbsSeeds_IDs)
    end
    if self.db.profile.moveInscription then
      Result[formatBagTitle(self, L["Inscription"], converttohex(self.db.profile.color.Inscription))] =
        AddToSet(Inscription_IDs)
    end
    if self.db.profile.moveJewelcrafting then
      Result[formatBagTitle(self, L["Jewelcrafting"], converttohex(self.db.profile.color.Jewelcrafting))] =
        AddToSet(Jewelcrafting_IDs)
    end
    if self.db.profile.moveLeather then
      Result[formatBagTitle(self, L["Leather"], converttohex(self.db.profile.color.Leather))] = AddToSet(Leather_IDs)
    end
    if self.db.profile.moveLeatherBait then
      Result[formatBagTitle(self, L["Leather - Bait"], converttohex(self.db.profile.color.LeatherBait))] =
        AddToSet(LeatherBait_IDs)
    end
    if self.db.profile.moveMining then
      Result[formatBagTitle(self, L["Mining"], converttohex(self.db.profile.color.Mining))] = AddToSet(Mining_IDs)
    end
  end

  return Result
end

local setFilter = AdiBags:RegisterFilter("Dragonflight", 98, "ABEvent-1.0")
setFilter.uiName = string.format("|cffa00000%s|r", L["Dragonflight"])
setFilter.uiDesc = string.format(
  "%s\n|cffffd800%s: 2.0.8|r",
  L["Items from the Dragonflight expansion."],
  L["Filter version"]
)

function setFilter:OnInitialize()
  self.db = AdiBags.db:RegisterNamespace("Dragonflight", {
    profile = {
      coloredCategories = true,
      prefixCategories = "",
      customPrefix = "",
      coloredPrefix = true,
      moveMergedAchievementsUnlockables = false,
      moveHonorOurAncestors = false,
      moveLizisReinsMount = true,
      moveMagmashellMount = true,
      moveOttoMount = true,
      moveScrappyWorldsnailMount = true,
      moveTemperamentalSkyclawMount = true,
      moveTetrachromancerAchievement = true,
      moveMergedConsumables = false,
      moveBandages = true,
      moveCauldrons = true,
      moveContracts = true,
      moveCraftingPotions = true,
      moveFood = true,
      moveIncense = true,
      movePhials = true,
      movePotions = true,
      moveRubyFeast = true,
      moveRunes = true,
      moveStatues = true,
      moveTools = true,
      moveMergedElementalTradeGoods = true,
      moveAwakenedElementals = true,
      moveRousingElementals = true,
      moveGeneralCraftingReagents = true,
      moveProfessionGear = true,
      moveProfessionKnowledge = true,
      moveDarkmoonCards = true,
      moveDrakewatcherManuscripts = true,
      moveFortuneCards = true,
      moveReputationItems = true,
      moveTreasureMaps = true,
      moveTreasureSacks = true,
      moveMergedPreEvent = false,
      movePreEventCurrency = true,
      movePreEventGear = true,
      moveMergedProfessions = false,
      moveAlchemyFlasks = false,
      moveCloth = false,
      moveCooking = false,
      moveEnchanting = false,
      moveEnchantingInsightoftheBlue = false,
      moveEngineering = false,
      moveFishingLures = false,
      moveHerbs = false,
      moveHerbsSeeds = false,
      moveInscription = false,
      moveJewelcrafting = false,
      moveLeather = false,
      moveLeatherBait = false,
      moveMining = false,

      color = {
        prefix = converttorgb("a00000", true),
        mergedAchievementsUnlockables = converttorgb("f7cb15", true),
        HonorOurAncestors = converttorgb("76bed0", true),
        LizisReinsMount = converttorgb("878e88", true),
        MagmashellMount = converttorgb("ff8c61", true),
        OttoMount = converttorgb("1d24e2", true),
        ScrappyWorldsnailMount = converttorgb("ce6a85", true),
        TemperamentalSkyclawMount = converttorgb("f55d3e", true),
        TetrachromancerAchievement = converttorgb("fcccbf", true),
        mergedConsumables = converttorgb("7aa36f", true),
        Bandages = converttorgb("ab3428", true),
        Cauldrons = converttorgb("07393c", true),
        Contracts = converttorgb("f2cc8f", true),
        CraftingPotions = converttorgb("ebb134", true),
        Food = converttorgb("34eb9e", true),
        Incense = converttorgb("f4f1de", true),
        Phials = converttorgb("d295bf", true),
        Potions = converttorgb("ebb134", true),
        RubyFeast = converttorgb("ab3428", true),
        Runes = converttorgb("9bc53d", true),
        Statues = converttorgb("36494e", true),
        Tools = converttorgb("ad5d4e", true),
        mergedElementalTradeGoods = converttorgb("644bff", true),
        AwakenedElementals = converttorgb("644bff", true),
        RousingElementals = converttorgb("644bff", true),
        GeneralCraftingReagents = converttorgb("51479c", true),
        ProfessionGear = converttorgb("ffd883", true),
        ProfessionKnowledge = converttorgb("33937f", true),
        DarkmoonCards = converttorgb("48aa00", true),
        DrakewatcherManuscripts = converttorgb("33937f", true),
        FortuneCards = converttorgb("6cff00", true),
        ReputationItems = converttorgb("1eff00", true),
        TreasureMaps = converttorgb("d900d2", true),
        TreasureSacks = converttorgb("fff000", true),
        mergedPreEvent = converttorgb("644bff", true),
        PreEventCurrency = converttorgb("0060a2", true),
        PreEventGear = converttorgb("0050a2", true),
        mergedProfessions = converttorgb("a36f6f", true),
        AlchemyFlasks = converttorgb("91ffe9", true),
        Cloth = converttorgb("ff7e00", true),
        Cooking = converttorgb("ff0072", true),
        Enchanting = converttorgb("96ff00", true),
        EnchantingInsightoftheBlue = converttorgb("96ff00", true),
        Engineering = converttorgb("787878", true),
        FishingLures = converttorgb("40bcd8", true),
        Herbs = converttorgb("00ff36", true),
        HerbsSeeds = converttorgb("bfffbc", true),
        Inscription = converttorgb("4dfaf8", true),
        Jewelcrafting = converttorgb("514dfa", true),
        Leather = converttorgb("865b00", true),
        LeatherBait = converttorgb("f4f1de", true),
        Mining = converttorgb("898396", true),
      },
    },
  })
end

function setFilter:Update()
  MatchIDs = nil
  self:SendMessage("AdiBags_FiltersChanged")
end

function setFilter:OnEnable()
  AdiBags:UpdateFilters()
end

function setFilter:OnDisable()
  AdiBags:UpdateFilters()
end

function setFilter:Filter(slotData)
  MatchIDs = MatchIDs or MatchIDs_Init(self)
  for i, name in pairs(MatchIDs) do
    -- Override Method
    if MatchIDs[i]["override"] then
      slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
      if slotData["loc"] and slotData["loc"]:IsValid() then
        if MatchIDs[i]["override"](slotData.loc) then
          return i
        end
      end

      -- Bonus Condition (triggers when bonus condition is not fulfilled)
    elseif MatchIDs[i]["bonus_condition"] then
      if name[slotData.itemId] then
        slotData["loc"] = ItemLocation:CreateFromBagAndSlot(slotData.bag, slotData.slot)
        if slotData["loc"] and slotData["loc"]:IsValid() then
          if not MatchIDs[i]["bonus_condition"](slotData.loc) then
            -- THERE IS A NOT HERE!
            return i
          end
        end
      end

      -- Standard ID Matching
    elseif name[slotData.itemId] then
      return i
    end
  end
end

function setFilter:GetOptions()
  return {
    general_config = {
      type = "group",
      name = L["General Settings"],
      desc = L["Settings affecting all categories."],
      inline = true,
      order = 1,
      args = {
        description = {
          type = "description",
          name = string.format(
            "%s |cffffd800%s |cff529F00%s|r",
            L["These settings affect all categories of this filter."],
            L["If you overwrite prefix or categorie color, you either need to toggle the color setting twice or reload."],
            L["AdiBags never intended to use icons, so they are glitchy. Make sure to disable prefix color, if you use an icon."]
          ),
          order = 1,
        },
        coloredCategories = {
          name = string.format("|cffFDFD96%s|r", L["Colored Categories"]),
          desc = L["Should Categories be colored?"],
          width = "full",
          type = "toggle",
          order = 10,
        },
        prefixCategories = {
          name = L["Prefix Categories"],
          desc = L["Select a prefix for the categories, if you like."],
          type = "select",
          order = 20,
          values = {
            [""] = L["None"],
            ["!CUSTOM"] = L["Custom Prefix"],
            ["DF"] = "DF",
            ["DF-"] = "DF-",
            ["9."] = "9.",
            ["|T4734167:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4734167:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T236469:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T236469:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T236473:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T236473:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T236471:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T236471:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T236472:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T236472:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4640486:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4640486:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4397694:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4397694:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4397691:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4397691:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4397692:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4397692:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4397690:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4397690:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
            ["|T4397693:" .. AdiBags.HEADER_SIZE .. ":" .. AdiBags.HEADER_SIZE .. ":-2:-10|t"] = "|T4397693:"
              .. AdiBags.HEADER_SIZE
              .. "|t",
          },
        },
        customPrefix = {
          name = L["Custom Prefix"],
          desc = L["Enter a custom prefix for the categories."],
          type = "input",
          order = 30,
          width = "full",
          disabled = function()
            return self.db.profile.prefixCategories ~= "!CUSTOM"
          end,
        },
        coloredPrefix = {
          name = string.format("|cffB9FFB9%s|r", L["Colored Prefix"]),
          desc = L["Should the prefix be colored to the filter color? (Only works for text-prefixes, for obvious reasons.)"],
          type = "toggle",
          order = 40,
        },
        prefixColor = {
          name = L["Prefix Color"],
          desc = L["Select a color for the prefix."],
          type = "color",
          order = 50,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.coloredPrefix
          end,
          get = function()
            local color = self.db.profile.color.prefix
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.prefix
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    AchievementsUnlockables_config = {
      type = "group",
      name = L["Achievements & Unlockables"],
      desc = "", -- doesnt work,
      inline = true,
      order = 52,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items which are used for achievements or unlockable mounts. Most of them lose their value, once the achievement or mount is unlocked."],
          order = 53,
        },
        moveMergedAchievementsUnlockables = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Achievements & Unlockables"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Achievements & Unlockables"]),
          type = "toggle",
          width = 1.5,
          order = 54,
        },
        colorMergedAchievementsUnlockables = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Achievements & Unlockables"]),
          type = "color",
          order = 55,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.mergedAchievementsUnlockables
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedAchievementsUnlockables
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_1 = {
          type = "header",
          name = "",
          order = 56,
        },
        moveHonorOurAncestors = {
          name = L["Honor Our Ancestors"],
          desc = L["CONTAINS ITEMS FROM OTHER CATEGORIES! These items can be handed in the Ohn'ahran Plains (while under the effect of Essence of Awakening) to get this achievement."],
          type = "toggle",
          width = 1.5,
          order = 57,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorHonorOurAncestors = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Honor Our Ancestors"]),
          type = "color",
          order = 58,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.HonorOurAncestors
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.HonorOurAncestors
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_2 = {
          type = "header",
          name = "",
          order = 59,
        },
        moveLizisReinsMount = {
          name = L["Lizis Reins (Mount)"],
          desc = L["A mount that can be unlocked in Ohn'iri Springs in the Ohn'ahran Plains. Requires to hand in one of these items once a day."],
          type = "toggle",
          width = 1.5,
          order = 60,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorLizisReinsMount = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Lizis Reins (Mount)"]),
          type = "color",
          order = 61,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.LizisReinsMount
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.LizisReinsMount
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_3 = {
          type = "header",
          name = "",
          order = 62,
        },
        moveMagmashellMount = {
          name = L["Magmashell (Mount)"],
          desc = L["This category only contains the Empty Magma Shell required to get the Magmashell Mount in the Waking Shores."],
          type = "toggle",
          width = 1.5,
          order = 63,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorMagmashellMount = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Magmashell (Mount)"]),
          type = "color",
          order = 64,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.MagmashellMount
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.MagmashellMount
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_4 = {
          type = "header",
          name = "",
          order = 65,
        },
        moveOttoMount = {
          name = L["Otto (Mount)"],
          desc = L["This section contains items which are needed to unlock Otto, the fishing ottusk mount."],
          type = "toggle",
          width = 1.5,
          order = 66,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorOttoMount = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Otto (Mount)"]),
          type = "color",
          order = 67,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.OttoMount
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.OttoMount
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_5 = {
          type = "header",
          name = "",
          order = 68,
        },
        moveScrappyWorldsnailMount = {
          name = L["Scrappy Worldsnail (Mount)"],
          desc = L["This category only contains the Membership and the Magmotes required to get the Scrappy Worldsnail Mount in the Waking Shores."],
          type = "toggle",
          width = 1.5,
          order = 69,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorScrappyWorldsnailMount = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Scrappy Worldsnail (Mount)"]),
          type = "color",
          order = 70,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.ScrappyWorldsnailMount
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ScrappyWorldsnailMount
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_6 = {
          type = "header",
          name = "",
          order = 71,
        },
        moveTemperamentalSkyclawMount = {
          name = L["Temperamental Skyclaw (Mount)"],
          desc = L["To get Temperamental Skyclaw you have to collect these 3 types of food and turn it to Zon'Wogi Stable Master at Three-Falls Lookout (Azure Span)."],
          type = "toggle",
          width = 1.5,
          order = 72,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorTemperamentalSkyclawMount = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Temperamental Skyclaw (Mount)"]),
          type = "color",
          order = 73,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.TemperamentalSkyclawMount
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TemperamentalSkyclawMount
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_7 = {
          type = "header",
          name = "",
          order = 74,
        },
        moveTetrachromancerAchievement = {
          name = L["Tetrachromancer (Achievement)"],
          desc = L["This category contains hunting companion colors needed for the achievement."],
          type = "toggle",
          width = 1.5,
          order = 75,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
        },
        colorTetrachromancerAchievement = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Tetrachromancer (Achievement)"]),
          type = "color",
          order = 76,
          disabled = function()
            return self.db.profile.moveMergedAchievementsUnlockables
          end,
          get = function()
            local color = self.db.profile.color.TetrachromancerAchievement
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TetrachromancerAchievement
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Consumables_config = {
      type = "group",
      name = L["Consumables"],
      desc = "", -- doesnt work,
      inline = true,
      order = 77,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items you can eat or use to improve yourself"],
          order = 78,
        },
        moveMergedConsumables = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Consumables"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Consumables"]),
          type = "toggle",
          width = 1.5,
          order = 79,
        },
        colorMergedConsumables = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Consumables"]),
          type = "color",
          order = 80,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.mergedConsumables
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedConsumables
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_8 = {
          type = "header",
          name = "",
          order = 81,
        },
        moveBandages = {
          name = L["Bandages"],
          desc = L["Bandages, to patch up your broken friends :)"],
          type = "toggle",
          width = 1.5,
          order = 82,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorBandages = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Bandages"]),
          type = "color",
          order = 83,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Bandages
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Bandages
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_9 = {
          type = "header",
          name = "",
          order = 84,
        },
        moveCauldrons = {
          name = L["Cauldrons"],
          desc = L["Cauldrons, to share your soup with friends :)"],
          type = "toggle",
          width = 1.5,
          order = 85,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorCauldrons = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Cauldrons"]),
          type = "color",
          order = 86,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Cauldrons
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Cauldrons
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_10 = {
          type = "header",
          name = "",
          order = 87,
        },
        moveContracts = {
          name = L["Contracts"],
          desc = L["Contracts give additional reputation when completing world quests in the Dragon Isles."],
          type = "toggle",
          width = 1.5,
          order = 88,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorContracts = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Contracts"]),
          type = "color",
          order = 89,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Contracts
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Contracts
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_11 = {
          type = "header",
          name = "",
          order = 90,
        },
        moveCraftingPotions = {
          name = L["Crafting Potions"],
          desc = L["Potions which improve crafting or collecting"],
          type = "toggle",
          width = 1.5,
          order = 91,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorCraftingPotions = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Crafting Potions"]),
          type = "color",
          order = 92,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.CraftingPotions
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.CraftingPotions
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_12 = {
          type = "header",
          name = "",
          order = 93,
        },
        moveFood = {
          name = L["Food"],
          desc = L["Food added in the Dragonflight expansion"],
          type = "toggle",
          width = 1.5,
          order = 94,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorFood = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Food"]),
          type = "color",
          order = 95,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Food
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Food
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_13 = {
          type = "header",
          name = "",
          order = 96,
        },
        moveIncense = {
          name = L["Incense"],
          desc = L["Incense to improve crafting ability or just for a nice smell"],
          type = "toggle",
          width = 1.5,
          order = 97,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorIncense = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Incense"]),
          type = "color",
          order = 98,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Incense
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Incense
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_14 = {
          type = "header",
          name = "",
          order = 99,
        },
        movePhials = {
          name = L["Phials"],
          desc = L["Phials added in the Dragonflight expansion"],
          type = "toggle",
          width = 1.5,
          order = 100,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorPhials = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Phials"]),
          type = "color",
          order = 101,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Phials
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Phials
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_15 = {
          type = "header",
          name = "",
          order = 102,
        },
        movePotions = {
          name = L["Potions"],
          desc = L["Potions added in the Dragonflight expansion"],
          type = "toggle",
          width = 1.5,
          order = 103,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorPotions = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Potions"]),
          type = "color",
          order = 104,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Potions
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Potions
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_16 = {
          type = "header",
          name = "",
          order = 105,
        },
        moveRubyFeast = {
          name = L["Ruby Feast"],
          desc = L["Food from the Ruby Feast - only cosmetic effects work outside of the open world."],
          type = "toggle",
          width = 1.5,
          order = 106,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorRubyFeast = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Ruby Feast"]),
          type = "color",
          order = 107,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.RubyFeast
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.RubyFeast
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_17 = {
          type = "header",
          name = "",
          order = 108,
        },
        moveRunes = {
          name = L["Runes"],
          desc = L["Contains runes & vantus runes which improving your combat ability."],
          type = "toggle",
          width = 1.5,
          order = 109,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorRunes = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Runes"]),
          type = "color",
          order = 110,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Runes
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Runes
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_18 = {
          type = "header",
          name = "",
          order = 111,
        },
        moveStatues = {
          name = L["Statues"],
          desc = L["Statues crafted by Jewelcrafters. They improve various things."],
          type = "toggle",
          width = 1.5,
          order = 112,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorStatues = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Statues"]),
          type = "color",
          order = 113,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Statues
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Statues
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_19 = {
          type = "header",
          name = "",
          order = 114,
        },
        moveTools = {
          name = L["Tools"],
          desc = L["Contains various tools, helpful in the Dragon Isles."],
          type = "toggle",
          width = 1.5,
          order = 115,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
        },
        colorTools = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Tools"]),
          type = "color",
          order = 116,
          disabled = function()
            return self.db.profile.moveMergedConsumables
          end,
          get = function()
            local color = self.db.profile.color.Tools
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Tools
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    ElementalTradeGoods_config = {
      type = "group",
      name = L["Elemental Trade Goods"],
      desc = "", -- doesnt work,
      inline = true,
      order = 117,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Awakened and Rousing Elemental Trade Goods"],
          order = 118,
        },
        moveMergedElementalTradeGoods = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Elemental Trade Goods"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Elemental Trade Goods"]),
          type = "toggle",
          width = 1.5,
          order = 119,
        },
        colorMergedElementalTradeGoods = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Elemental Trade Goods"]),
          type = "color",
          order = 120,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedElementalTradeGoods
          end,
          get = function()
            local color = self.db.profile.color.mergedElementalTradeGoods
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedElementalTradeGoods
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_20 = {
          type = "header",
          name = "",
          order = 121,
        },
        moveAwakenedElementals = {
          name = L["Awakened Elementals"],
          desc = L["Awakened Elementals"],
          type = "toggle",
          width = 1.5,
          order = 122,
          disabled = function()
            return self.db.profile.moveMergedElementalTradeGoods
          end,
        },
        colorAwakenedElementals = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Awakened Elementals"]),
          type = "color",
          order = 123,
          disabled = function()
            return self.db.profile.moveMergedElementalTradeGoods
          end,
          get = function()
            local color = self.db.profile.color.AwakenedElementals
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.AwakenedElementals
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_21 = {
          type = "header",
          name = "",
          order = 124,
        },
        moveRousingElementals = {
          name = L["Rousing Elementals"],
          desc = L["Rousing Elementals"],
          type = "toggle",
          width = 1.5,
          order = 125,
          disabled = function()
            return self.db.profile.moveMergedElementalTradeGoods
          end,
        },
        colorRousingElementals = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Rousing Elementals"]),
          type = "color",
          order = 126,
          disabled = function()
            return self.db.profile.moveMergedElementalTradeGoods
          end,
          get = function()
            local color = self.db.profile.color.RousingElementals
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.RousingElementals
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    GeneralProfessionItems_config = {
      type = "group",
      name = L["General Profession Items"],
      desc = "", -- doesnt work,
      inline = true,
      order = 127,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items which are used in multiple professions."],
          order = 128,
        },
        moveGeneralCraftingReagents = {
          name = L["General Crafting Reagents"],
          desc = L["General Crafting Reagents, used by multiple professions"],
          type = "toggle",
          width = 1.5,
          order = 129,
        },
        colorGeneralCraftingReagents = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["General Crafting Reagents"]),
          type = "color",
          order = 130,
          disabled = function()
            return self.db.profile.moveMergedGeneralProfessionItems
          end,
          get = function()
            local color = self.db.profile.color.GeneralCraftingReagents
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.GeneralCraftingReagents
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_22 = {
          type = "header",
          name = "",
          order = 131,
        },
        moveProfessionGear = {
          name = L["Profession Gear"],
          desc = L["Specialized gear which improves your profession"],
          type = "toggle",
          width = 1.5,
          order = 132,
        },
        colorProfessionGear = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Profession Gear"]),
          type = "color",
          order = 133,
          disabled = function()
            return self.db.profile.moveMergedGeneralProfessionItems
          end,
          get = function()
            local color = self.db.profile.color.ProfessionGear
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ProfessionGear
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_23 = {
          type = "header",
          name = "",
          order = 134,
        },
        moveProfessionKnowledge = {
          name = L["Profession Knowledge"],
          desc = L["Items that provide profession knowledge"],
          type = "toggle",
          width = 1.5,
          order = 135,
        },
        colorProfessionKnowledge = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Profession Knowledge"]),
          type = "color",
          order = 136,
          disabled = function()
            return self.db.profile.moveMergedGeneralProfessionItems
          end,
          get = function()
            local color = self.db.profile.color.ProfessionKnowledge
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ProfessionKnowledge
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    OtherItems_config = {
      type = "group",
      name = L["Other Items"],
      desc = "", -- doesnt work,
      inline = true,
      order = 137,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Other items not really fitting in another category."],
          order = 138,
        },
        moveDarkmoonCards = {
          name = L["Darkmoon Cards"],
          desc = L["Darkmoon Cards"],
          type = "toggle",
          width = 1.5,
          order = 139,
        },
        colorDarkmoonCards = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Darkmoon Cards"]),
          type = "color",
          order = 140,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.DarkmoonCards
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.DarkmoonCards
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_24 = {
          type = "header",
          name = "",
          order = 141,
        },
        moveDrakewatcherManuscripts = {
          name = L["Drakewatcher Manuscripts"],
          desc = L["Drakewatcher Manuscripts for learning new customizations for your Dragonriding mounts"],
          type = "toggle",
          width = 1.5,
          order = 142,
        },
        colorDrakewatcherManuscripts = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Drakewatcher Manuscripts"]),
          type = "color",
          order = 143,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.DrakewatcherManuscripts
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.DrakewatcherManuscripts
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_25 = {
          type = "header",
          name = "",
          order = 144,
        },
        moveFortuneCards = {
          name = L["Fortune Cards"],
          desc = L["Fortune Cards"],
          type = "toggle",
          width = 1.5,
          order = 145,
        },
        colorFortuneCards = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Fortune Cards"]),
          type = "color",
          order = 146,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.FortuneCards
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.FortuneCards
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_26 = {
          type = "header",
          name = "",
          order = 147,
        },
        moveReputationItems = {
          name = L["Reputation Items"],
          desc = L["Contains Items which can be directly traded in for reputation/renown, as well as items needed for Wrathion & Sabellian"],
          type = "toggle",
          width = 1.5,
          order = 148,
        },
        colorReputationItems = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Reputation Items"]),
          type = "color",
          order = 149,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.ReputationItems
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.ReputationItems
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_27 = {
          type = "header",
          name = "",
          order = 150,
        },
        moveTreasureMaps = {
          name = L["Treasure Maps"],
          desc = L["Maps to Treasure found in the Dragon Isles"],
          type = "toggle",
          width = 1.5,
          order = 151,
        },
        colorTreasureMaps = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Treasure Maps"]),
          type = "color",
          order = 152,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.TreasureMaps
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TreasureMaps
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_28 = {
          type = "header",
          name = "",
          order = 153,
        },
        moveTreasureSacks = {
          name = L["Treasure Sacks"],
          desc = L["Treasure Sacks given by the Great Swog, Saviour of all Dragonkind."],
          type = "toggle",
          width = 1.5,
          order = 154,
        },
        colorTreasureSacks = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Treasure Sacks"]),
          type = "color",
          order = 155,
          disabled = function()
            return self.db.profile.moveMergedOtherItems
          end,
          get = function()
            local color = self.db.profile.color.TreasureSacks
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.TreasureSacks
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    PreEvent_config = {
      type = "group",
      name = L["PreEvent"],
      desc = "", -- doesnt work,
      inline = true,
      order = 156,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items from the Dragonflight Pre-Event."],
          order = 157,
        },
        moveMergedPreEvent = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["PreEvent"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["PreEvent"]),
          type = "toggle",
          width = 1.5,
          order = 158,
        },
        colorMergedPreEvent = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["PreEvent"]),
          type = "color",
          order = 159,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedPreEvent
          end,
          get = function()
            local color = self.db.profile.color.mergedPreEvent
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedPreEvent
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_29 = {
          type = "header",
          name = "",
          order = 160,
        },
        movePreEventCurrency = {
          name = L["PreEvent Currency"],
          desc = L["Currency-like items dropped in the Dragonflight Pre-Patch Event"],
          type = "toggle",
          width = 1.5,
          order = 161,
          disabled = function()
            return self.db.profile.moveMergedPreEvent
          end,
        },
        colorPreEventCurrency = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["PreEvent Currency"]),
          type = "color",
          order = 162,
          disabled = function()
            return self.db.profile.moveMergedPreEvent
          end,
          get = function()
            local color = self.db.profile.color.PreEventCurrency
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.PreEventCurrency
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_30 = {
          type = "header",
          name = "",
          order = 163,
        },
        movePreEventGear = {
          name = L["PreEvent Gear"],
          desc = L["Gear dropped or bought in the Dragonflight Pre-Patch Event"],
          type = "toggle",
          width = 1.5,
          order = 164,
          disabled = function()
            return self.db.profile.moveMergedPreEvent
          end,
        },
        colorPreEventGear = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["PreEvent Gear"]),
          type = "color",
          order = 165,
          disabled = function()
            return self.db.profile.moveMergedPreEvent
          end,
          get = function()
            local color = self.db.profile.color.PreEventGear
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.PreEventGear
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
    Professions_config = {
      type = "group",
      name = L["Professions"],
      desc = "", -- doesnt work,
      inline = true,
      order = 166,
      args = {
        Legendaries_desc = {
          type = "description",
          name = L["Items in professions"],
          order = 167,
        },
        moveMergedProfessions = {
          name = string.format(L["%sMerge %s%s"], "|cffffd800", L["Professions"], "|r"),
          desc = string.format(L["Merge all %s into a single category."], L["Professions"]),
          type = "toggle",
          width = 1.5,
          order = 168,
        },
        colorMergedProfessions = {
          name = L["Color"],
          desc = string.format(L["Select a color for the merged %s category."], L["Professions"]),
          type = "color",
          order = 169,
          hasAlpha = false,
          disabled = function()
            return not self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.mergedProfessions
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.mergedProfessions
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_31 = {
          type = "header",
          name = "",
          order = 170,
        },
        moveAlchemyFlasks = {
          name = L["Alchemy Flasks"],
          desc = L["Crafting Reagents categorically belonging to Alchemy"],
          type = "toggle",
          width = 1.5,
          order = 171,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorAlchemyFlasks = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Alchemy Flasks"]),
          type = "color",
          order = 172,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.AlchemyFlasks
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.AlchemyFlasks
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_32 = {
          type = "header",
          name = "",
          order = 173,
        },
        moveCloth = {
          name = L["Cloth"],
          desc = L["Crafting Reagents categorically belonging to Cloth"],
          type = "toggle",
          width = 1.5,
          order = 174,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorCloth = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Cloth"]),
          type = "color",
          order = 175,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Cloth
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Cloth
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_33 = {
          type = "header",
          name = "",
          order = 176,
        },
        moveCooking = {
          name = L["Cooking"],
          desc = L["Crafting Reagents categorically belonging to Cooking"],
          type = "toggle",
          width = 1.5,
          order = 177,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorCooking = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Cooking"]),
          type = "color",
          order = 178,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Cooking
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Cooking
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_34 = {
          type = "header",
          name = "",
          order = 179,
        },
        moveEnchanting = {
          name = L["Enchanting"],
          desc = L["Crafting Reagents categorically belonging to Enchanting"],
          type = "toggle",
          width = 1.5,
          order = 180,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorEnchanting = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Enchanting"]),
          type = "color",
          order = 181,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Enchanting
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Enchanting
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_35 = {
          type = "header",
          name = "",
          order = 182,
        },
        moveEnchantingInsightoftheBlue = {
          name = L["Enchanting - Insight of the Blue"],
          desc = L["Items that can be found & disenchanted when 'Insight of the Blue' (Enchanting Perk) is skilled."],
          type = "toggle",
          width = 1.5,
          order = 183,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorEnchantingInsightoftheBlue = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Enchanting - Insight of the Blue"]),
          type = "color",
          order = 184,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.EnchantingInsightoftheBlue
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.EnchantingInsightoftheBlue
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_36 = {
          type = "header",
          name = "",
          order = 185,
        },
        moveEngineering = {
          name = L["Engineering"],
          desc = L["Crafting Reagents categorically belonging to Engineering"],
          type = "toggle",
          width = 1.5,
          order = 186,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorEngineering = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Engineering"]),
          type = "color",
          order = 187,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Engineering
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Engineering
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_37 = {
          type = "header",
          name = "",
          order = 188,
        },
        moveFishingLures = {
          name = L["Fishing Lures"],
          desc = L["Fishing Lures for catching specific fish"],
          type = "toggle",
          width = 1.5,
          order = 189,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorFishingLures = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Fishing Lures"]),
          type = "color",
          order = 190,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.FishingLures
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.FishingLures
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_38 = {
          type = "header",
          name = "",
          order = 191,
        },
        moveHerbs = {
          name = L["Herbs"],
          desc = L["Crafting Reagents categorically belonging to Herbs"],
          type = "toggle",
          width = 1.5,
          order = 192,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorHerbs = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Herbs"]),
          type = "color",
          order = 193,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Herbs
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Herbs
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_39 = {
          type = "header",
          name = "",
          order = 194,
        },
        moveHerbsSeeds = {
          name = L["Herbs - Seeds"],
          desc = L["Seeds to plant into Rich Soil which in return grants some herbs"],
          type = "toggle",
          width = 1.5,
          order = 195,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorHerbsSeeds = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Herbs - Seeds"]),
          type = "color",
          order = 196,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.HerbsSeeds
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.HerbsSeeds
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_40 = {
          type = "header",
          name = "",
          order = 197,
        },
        moveInscription = {
          name = L["Inscription"],
          desc = L["Crafting Reagents categorically belonging to Inscription"],
          type = "toggle",
          width = 1.5,
          order = 198,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorInscription = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Inscription"]),
          type = "color",
          order = 199,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Inscription
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Inscription
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_41 = {
          type = "header",
          name = "",
          order = 200,
        },
        moveJewelcrafting = {
          name = L["Jewelcrafting"],
          desc = L["Crafting Reagents categorically belonging to Jewelcrafting"],
          type = "toggle",
          width = 1.5,
          order = 201,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorJewelcrafting = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Jewelcrafting"]),
          type = "color",
          order = 202,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Jewelcrafting
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Jewelcrafting
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_42 = {
          type = "header",
          name = "",
          order = 203,
        },
        moveLeather = {
          name = L["Leather"],
          desc = L["Crafting Reagents categorically belonging to Leather"],
          type = "toggle",
          width = 1.5,
          order = 204,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorLeather = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Leather"]),
          type = "color",
          order = 205,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Leather
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Leather
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_43 = {
          type = "header",
          name = "",
          order = 206,
        },
        moveLeatherBait = {
          name = L["Leather - Bait"],
          desc = L["Baits to attract skinnable creatures"],
          type = "toggle",
          width = 1.5,
          order = 207,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorLeatherBait = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Leather - Bait"]),
          type = "color",
          order = 208,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.LeatherBait
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.LeatherBait
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
        seperator_44 = {
          type = "header",
          name = "",
          order = 209,
        },
        moveMining = {
          name = L["Mining"],
          desc = L["Crafting Reagents categorically belonging to Mining"],
          type = "toggle",
          width = 1.5,
          order = 210,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
        },
        colorMining = {
          name = L["Color"],
          desc = string.format(L["Select a color for %s."], L["Mining"]),
          type = "color",
          order = 211,
          disabled = function()
            return self.db.profile.moveMergedProfessions
          end,
          get = function()
            local color = self.db.profile.color.Mining
            AdiBags:UpdateFilters()
            return color.r, color.g, color.b
          end,
          set = function(_, r, g, b)
            local color = self.db.profile.color.Mining
            color.r, color.g, color.b = r, g, b
            AdiBags:UpdateFilters()
          end,
        },
      },
    },
  },
    AdiBags:GetOptionHandler(self, false, function()
      return self:Update()
    end)
end
